Module cookbook

Module cookbook 

Cookbook of common patterns for building ACP components Cookbook of common patterns for building ACP components.

This module has moved to the agent_client_protocol_cookbook crate, which provides more comprehensive examples with full access to the entire agent-client-protocol ecosystem.

See agent_client_protocol_cookbook for:

  • Clients - Connect to an existing agent and send prompts
  • Proxies - Sit between client and agent to add capabilities (like MCP tools)
  • Agents - Respond to prompts with AI-powered responses