#[non_exhaustive]pub enum AgentResponse {
Show 15 variants
InitializeResponse(InitializeResponse),
AuthenticateResponse(AuthenticateResponse),
LogoutResponse(LogoutResponse),
NewSessionResponse(NewSessionResponse),
LoadSessionResponse(LoadSessionResponse),
ListSessionsResponse(ListSessionsResponse),
DeleteSessionResponse(DeleteSessionResponse),
ForkSessionResponse(ForkSessionResponse),
ResumeSessionResponse(ResumeSessionResponse),
CloseSessionResponse(CloseSessionResponse),
SetSessionModeResponse(SetSessionModeResponse),
SetSessionConfigOptionResponse(SetSessionConfigOptionResponse),
PromptResponse(PromptResponse),
ExtMethodResponse(ExtResponse),
MessageMcpResponse(MessageMcpResponse),
}Expand description
All possible responses that an agent can send to a client.
This enum is used internally for routing RPC responses. You typically won’t need to use this directly - the responses are handled automatically by the connection.
These are responses to the corresponding ClientRequest variants.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
InitializeResponse(InitializeResponse)
AuthenticateResponse(AuthenticateResponse)
LogoutResponse(LogoutResponse)
NewSessionResponse(NewSessionResponse)
LoadSessionResponse(LoadSessionResponse)
ListSessionsResponse(ListSessionsResponse)
DeleteSessionResponse(DeleteSessionResponse)
ForkSessionResponse(ForkSessionResponse)
Available on crate feature
unstable_session_fork only.ResumeSessionResponse(ResumeSessionResponse)
CloseSessionResponse(CloseSessionResponse)
SetSessionModeResponse(SetSessionModeResponse)
SetSessionConfigOptionResponse(SetSessionConfigOptionResponse)
PromptResponse(PromptResponse)
ExtMethodResponse(ExtResponse)
MessageMcpResponse(MessageMcpResponse)
Available on crate feature
unstable_mcp_over_acp only.Trait Implementations
Sourceimpl Clone for AgentResponse
impl Clone for AgentResponse
Sourcefn clone(&self) -> AgentResponse
fn clone(&self) -> AgentResponse
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for AgentResponse
impl Debug for AgentResponse
Sourceimpl<'de> Deserialize<'de> for AgentResponse
impl<'de> Deserialize<'de> for AgentResponse
Sourcefn deserialize<__D>(
__deserializer: __D,
) -> Result<AgentResponse, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(
__deserializer: __D,
) -> Result<AgentResponse, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl IntoV2 for AgentResponse
impl IntoV2 for AgentResponse
Sourcetype Output = AgentResponse
type Output = AgentResponse
The corresponding v2 draft type.
Sourcefn into_v2(
self,
) -> Result<<AgentResponse as IntoV2>::Output, ProtocolConversionError>
fn into_v2( self, ) -> Result<<AgentResponse as IntoV2>::Output, ProtocolConversionError>
Converts this value into the corresponding v2 draft type. Read more
Sourceimpl JsonRpcResponse for AgentResponse
impl JsonRpcResponse for AgentResponse
Sourceimpl JsonSchema for AgentResponse
impl JsonSchema for AgentResponse
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl Serialize for AgentResponse
impl Serialize for AgentResponse
Sourcefn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
fn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
Serialize this value into the given Serde serializer. Read more