Handled

Enum Handled 

pub enum Handled<T> {
    Yes,
    No {
        message: T,
        retry: bool,
    },
}
Return type from JrHandler; indicates whether the request was handled or not.

Variants



Yes

The message was handled



No

The message was not handled; returns the original value.

If retry is true,

Fields

message: T

The message to be passed to subsequent handlers (typically the original message, but it may have been mutated.)

retry: bool

If true, request the message to be queued and retried with dynamic handlers as they are added.

This is used for managing session updates since the dynamic handler for a session cannot be added until the response to the new session request has been processed and there may be updates that get processed at the same time.