Module handler

Module handler 

JSON-RPC handler types for building custom message handlers Handler types for building custom JSON-RPC message handlers.

This module contains the handler types used by Builder to process incoming messages. Most users won’t need to use these types directly, as the builder methods on Builder handle the construction automatically.

Structs

NullHandler
Null handler that accepts no messages.

Traits

HandleDispatchFrom
Handlers process incoming JSON-RPC messages on a connection.