Module jsonrpcmsg

Module jsonrpcmsg 

JSON-RPC message types.

This module re-exports types from the jsonrpcmsg crate that are transitively reachable through the public API (e.g., via Channel).

Users of the agent-client-protocol crate can use these types without adding a direct dependency on jsonrpcmsg.

Structs

Error
JSON-RPC error object
Request
JSON-RPC request object
Response
JSON-RPC response object

Enums

Id
Identifier types for JSON-RPC requests
Message
A message in a batch, which can be either a request or a response
Params
Parameter types for JSON-RPC requests