pub struct Error {
pub code: i32,
pub message: String,
pub data: Option<Value>,
}Expand description
JSON-RPC error object
Fields
code: i32A number that indicates the error type that occurred
message: StringA short description of the error
data: Option<Value>Additional information about the error
Implementations
Sourceimpl Error
impl Error
Sourcepub fn with_data(code: i32, message: String, data: Value) -> Error
pub fn with_data(code: i32, message: String, data: Value) -> Error
Create a new error with code, message, and data
Sourcepub fn parse_error() -> Error
pub fn parse_error() -> Error
Parse error (-32700)
Sourcepub fn invalid_request() -> Error
pub fn invalid_request() -> Error
Invalid request error (-32600)
Sourcepub fn method_not_found() -> Error
pub fn method_not_found() -> Error
Method not found error (-32601)
Sourcepub fn invalid_params() -> Error
pub fn invalid_params() -> Error
Invalid params error (-32602)
Sourcepub fn internal_error() -> Error
pub fn internal_error() -> Error
Internal error (-32603)
Sourcepub fn server_error(code: i32, message: String) -> Error
pub fn server_error(code: i32, message: String) -> Error
Server error (-32000 to -32099)