macro_rules! tool_fn {
() => { ... };
}Expand description
This is a hack that must be given as the final argument of
McpServerBuilder::tool_fn when defining stateless concurrent tools.
See tool_fn_mut! for the gory details.
macro_rules! tool_fn {
() => { ... };
}This is a hack that must be given as the final argument of
McpServerBuilder::tool_fn when defining stateless concurrent tools.
See tool_fn_mut! for the gory details.