pub enum EnabledTools {
DenyList(HashSet<String>),
AllowList(HashSet<String>),
}Expand description
Tracks which tools are enabled.
DenyList: All tools enabled except those in the set (default)AllowList: Only tools in the set are enabled
Variants
DenyList(HashSet<String>)
All tools enabled except those in the deny set.
AllowList(HashSet<String>)
Only tools in the allow set are enabled.
Implementations
Sourceimpl EnabledTools
impl EnabledTools
Sourcepub fn is_enabled(&self, name: &str) -> bool
pub fn is_enabled(&self, name: &str) -> bool
Check if a tool is enabled.