pub struct McpToolMetadata { /* private fields */ }Expand description
Runtime-neutral metadata for an MCP tool.
Implementations
Sourceimpl McpToolMetadata
impl McpToolMetadata
Sourcepub fn description(&self) -> &str
pub fn description(&self) -> &str
A description of what the tool does.
Sourcepub fn input_schema(&self) -> &Arc<McpToolSchema>
pub fn input_schema(&self) -> &Arc<McpToolSchema>
JSON Schema object defining the expected parameters for the tool.
Sourcepub fn output_schema(&self) -> Option<&Arc<McpToolSchema>>
pub fn output_schema(&self) -> Option<&Arc<McpToolSchema>>
Optional JSON Schema object defining the structure of the tool’s output.