McpToolRegistry

Struct McpToolRegistry 

pub struct McpToolRegistry<Counterpart: Role> { /* private fields */ }
Runtime-neutral registry for MCP tools.

Implementations

Source

impl<Counterpart: Role> McpToolRegistry<Counterpart>

pub fn set_instructions(&mut self, instructions: impl ToString)

Set the server instructions that are provided to the client.

pub fn instructions(&self) -> Option<&str>

Server instructions provided to the client.

pub fn register_tool(&mut self, tool: impl McpTool<Counterpart> + 'static)

Register a tool.

pub fn tools(&self) -> impl Iterator<Item = &RegisteredMcpTool<Counterpart>>

Return all registered tools in registration order.

pub fn enabled_tools( &self, ) -> impl Iterator<Item = &RegisteredMcpTool<Counterpart>>

Return enabled registered tools in registration order.

pub fn tool(&self, name: &str) -> Option<&RegisteredMcpTool<Counterpart>>

Return a registered tool by name, even if it is disabled.

pub fn enabled_tool( &self, name: &str, ) -> Option<&RegisteredMcpTool<Counterpart>>

Return an enabled tool by name.

pub fn contains_tool(&self, name: &str) -> bool

Check whether a tool is registered.

pub fn disable_all_tools(&mut self)

Disable all tools. After calling this, only tools explicitly enabled with enable_tool will be available.

pub fn enable_all_tools(&mut self)

Enable all tools. After calling this, all tools will be available except those explicitly disabled with disable_tool.

pub fn disable_tool(&mut self, name: &str) -> Result<(), Error>

Disable a specific tool by name.

Returns an error if the tool is not registered.

pub fn enable_tool(&mut self, name: &str) -> Result<(), Error>

Enable a specific tool by name.

Returns an error if the tool is not registered.