UntypedRole

Struct UntypedRole 

pub struct UntypedRole;
A dummy role you can use to exchange JSON-RPC messages without any knowledge of the underlying protocol. Don’t sue this.

Implementations

Source

impl UntypedRole

pub fn builder(self) -> Builder<Self>

Creates a new builder for a connection from this role.