Module schema

Module schema 

ACP protocol schema types - all message types, requests, responses, and supporting types ACP protocol schema types and message implementations.

This module contains all the types from the Agent-Client Protocol schema, including requests, responses, notifications, and supporting types. All types are re-exported flatly from this module.

Modules

v1
Agent Client Protocol v1 schema types.
v2unstable_protocol_v2
Agent Client Protocol v2 draft schema types.

Structs

InitializeProxyRequest
Initialize request for proxy components.
ProtocolVersion
Protocol version identifier.
SuccessorMessage
A message being sent to the successor component.

Enums

MaybeUndefined
Similar to Option, but it has three states, undefined, null and x.

Constants

METHOD_INITIALIZE_PROXY
JSON-RPC method name for proxy initialization.
METHOD_SUCCESSOR_MESSAGE
JSON-RPC method name for successor forwarding.

Traits

IntoMaybeUndefined
Utility trait for builder methods for optional values. This allows the caller to either pass in the value itself without wrapping it in Some, or to just pass in an Option if that is what they have, or set it back to undefined.
IntoOption
Utility trait for builder methods for optional values. This allows the caller to either pass in the value itself without wrapping it in Some, or to just pass in an Option if that is what they have.