#[non_exhaustive]pub enum McpServer {
Http(McpServerHttp),
Sse(McpServerSse),
Acp(McpServerAcp),
Stdio(McpServerStdio),
}Expand description
Configuration for connecting to an MCP (Model Context Protocol) server.
MCP servers provide tools and context that the agent can use when processing prompts.
See protocol docs: MCP Servers
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Http(McpServerHttp)
HTTP transport configuration
Only available when the Agent capabilities indicate mcp_capabilities.http is true.
Sse(McpServerSse)
SSE transport configuration
Only available when the Agent capabilities indicate mcp_capabilities.sse is true.
Acp(McpServerAcp)
unstable_mcp_over_acp only.UNSTABLE
This capability is not part of the spec yet, and may be removed or changed at any point.
ACP transport configuration
Only available when the Agent capabilities indicate mcp_capabilities.acp is true.
The MCP server is provided by an ACP component and communicates over the ACP channel.
Stdio(McpServerStdio)
Stdio transport configuration
All Agents MUST support this transport.