#[non_exhaustive]pub struct AuthCapabilities {
pub terminal: bool,
pub meta: Option<Map<String, Value>>,
}Expand description
UNSTABLE
This capability is not part of the spec yet, and may be removed or changed at any point.
Authentication capabilities supported by the client.
Advertised during initialization to inform the agent which authentication method types the client can handle. This governs opt-in types that require additional client-side support.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.terminal: boolWhether the client supports terminal authentication methods.
When true, the agent may include terminal entries in its authentication methods.
meta: Option<Map<String, Value>>The _meta property is reserved by ACP to allow clients and agents to attach additional metadata to their interactions. Implementations MUST NOT make assumptions about values at these keys.
See protocol docs: Extensibility
Implementations
Sourceimpl AuthCapabilities
impl AuthCapabilities
pub fn new() -> AuthCapabilities
unstable_auth_methods only.Sourcepub fn terminal(self, terminal: bool) -> AuthCapabilities
Available on crate feature unstable_auth_methods only.
pub fn terminal(self, terminal: bool) -> AuthCapabilities
unstable_auth_methods only.Whether the client supports terminal authentication methods.
When true, the agent may include AuthMethod::Terminal
entries in its authentication methods.
Sourcepub fn meta(self, meta: impl IntoOption<Map<String, Value>>) -> AuthCapabilities
Available on crate feature unstable_auth_methods only.
pub fn meta(self, meta: impl IntoOption<Map<String, Value>>) -> AuthCapabilities
unstable_auth_methods only.The _meta property is reserved by ACP to allow clients and agents to attach additional metadata to their interactions. Implementations MUST NOT make assumptions about values at these keys.
See protocol docs: Extensibility