AuthEnvVar

Struct AuthEnvVar 

#[non_exhaustive]
pub struct AuthEnvVar { pub name: String, pub label: Option<String>, pub secret: bool, pub optional: bool, pub meta: Option<Map<String, Value>>, }
UNSTABLE

This capability is not part of the spec yet, and may be removed or changed at any point.

Describes a single environment variable for an AuthMethodEnvVar authentication method.

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
name: String

The environment variable name (e.g. "OPENAI_API_KEY").

label: Option<String>

Human-readable label for this variable, displayed in client UI.

secret: bool

Whether this value is a secret (e.g. API key, token). Clients should use a password-style input for secret vars.

Defaults to true.

optional: bool

Whether this variable is optional.

Defaults to false.

meta: Option<Map<String, Value>>

The _meta property is reserved by ACP to allow clients and agents to attach additional metadata to their interactions. Implementations MUST NOT make assumptions about values at these keys.

See protocol docs: Extensibility

Implementations

Source

impl AuthEnvVar

pub fn new(name: impl Into<String>) -> AuthEnvVar

Available on crate feature unstable_auth_methods only.

Creates a new auth env var.

pub fn label(self, label: impl IntoOption<String>) -> AuthEnvVar

Available on crate feature unstable_auth_methods only.

Human-readable label for this variable, displayed in client UI.

pub fn secret(self, secret: bool) -> AuthEnvVar

Available on crate feature unstable_auth_methods only.

Whether this value is a secret (e.g. API key, token). Clients should use a password-style input for secret vars.

pub fn optional(self, optional: bool) -> AuthEnvVar

Available on crate feature unstable_auth_methods only.

Whether this variable is optional.

pub fn meta(self, meta: impl IntoOption<Map<String, Value>>) -> AuthEnvVar

Available on crate feature unstable_auth_methods only.

The _meta property is reserved by ACP to allow clients and agents to attach additional metadata to their interactions. Implementations MUST NOT make assumptions about values at these keys.

See protocol docs: Extensibility