#[non_exhaustive]pub struct ConnectMcpResponse {
pub connection_id: McpConnectionId,
pub meta: Option<Map<String, Value>>,
}Expand description
UNSTABLE
This capability is not part of the spec yet, and may be removed or changed at any point.
Response to mcp/connect.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.connection_id: McpConnectionIdThe unique identifier for this MCP-over-ACP connection.
meta: Option<Map<String, Value>>The _meta property is reserved by ACP to allow clients and agents to attach additional metadata to their interactions. Implementations MUST NOT make assumptions about values at these keys.
See protocol docs: Extensibility
Implementations
Sourceimpl ConnectMcpResponse
impl ConnectMcpResponse
pub fn new(connection_id: impl Into<McpConnectionId>) -> ConnectMcpResponse
Sourcepub fn meta(
self,
meta: impl IntoOption<Map<String, Value>>,
) -> ConnectMcpResponse
pub fn meta( self, meta: impl IntoOption<Map<String, Value>>, ) -> ConnectMcpResponse
The _meta property is reserved by ACP to allow clients and agents to attach additional metadata to their interactions. Implementations MUST NOT make assumptions about values at these keys.
See protocol docs: Extensibility