#[non_exhaustive]pub struct DisconnectMcpRequest {
pub connection_id: McpConnectionId,
pub meta: Option<Map<String, Value>>,
}Expand description
UNSTABLE
This capability is not part of the spec yet, and may be removed or changed at any point.
Request parameters for mcp/disconnect.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.connection_id: McpConnectionIdThe MCP-over-ACP connection to close.
meta: Option<Map<String, Value>>The _meta property is reserved by ACP to allow clients and agents to attach additional metadata to their interactions. Implementations MUST NOT make assumptions about values at these keys.
See protocol docs: Extensibility
Implementations
Sourceimpl DisconnectMcpRequest
impl DisconnectMcpRequest
pub fn new(connection_id: impl Into<McpConnectionId>) -> DisconnectMcpRequest
Sourcepub fn meta(
self,
meta: impl IntoOption<Map<String, Value>>,
) -> DisconnectMcpRequest
pub fn meta( self, meta: impl IntoOption<Map<String, Value>>, ) -> DisconnectMcpRequest
The _meta property is reserved by ACP to allow clients and agents to attach additional metadata to their interactions. Implementations MUST NOT make assumptions about values at these keys.
See protocol docs: Extensibility