#[non_exhaustive]pub struct ElicitationSessionScope {
pub session_id: SessionId,
pub tool_call_id: Option<ToolCallId>,
}Expand description
UNSTABLE
This capability is not part of the spec yet, and may be removed or changed at any point.
Session-scoped elicitation, optionally tied to a specific tool call.
When tool_call_id is set, the elicitation is tied to a specific tool call.
This is useful when an agent receives an elicitation from an MCP server
during a tool call and needs to redirect it to the user.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.session_id: SessionIdThe session this elicitation is tied to.
tool_call_id: Option<ToolCallId>Optional tool call within the session.
Implementations
Sourceimpl ElicitationSessionScope
impl ElicitationSessionScope
pub fn new(session_id: impl Into<SessionId>) -> ElicitationSessionScope
pub fn tool_call_id( self, tool_call_id: impl IntoOption<ToolCallId>, ) -> ElicitationSessionScope