#[non_exhaustive]pub struct ElicitationUrlMode {
pub scope: ElicitationScope,
pub elicitation_id: ElicitationId,
pub url: String,
}Expand description
UNSTABLE
This capability is not part of the spec yet, and may be removed or changed at any point.
URL-based elicitation mode where the client directs the user to a URL.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.scope: ElicitationScopeThe scope this elicitation is tied to.
elicitation_id: ElicitationIdThe unique identifier for this elicitation.
url: StringThe URL to direct the user to.
Implementations
Sourceimpl ElicitationUrlMode
impl ElicitationUrlMode
pub fn new( scope: impl Into<ElicitationScope>, elicitation_id: impl Into<ElicitationId>, url: impl Into<String>, ) -> ElicitationUrlMode