#[non_exhaustive]pub struct LogoutRequest {
pub meta: Option<Map<String, Value>>,
}Expand description
Request parameters for the logout method.
Terminates the current authenticated session.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.meta: Option<Map<String, Value>>The _meta property is reserved by ACP to allow clients and agents to attach additional metadata to their interactions. Implementations MUST NOT make assumptions about values at these keys.
See protocol docs: Extensibility
Implementations
Sourceimpl LogoutRequest
impl LogoutRequest
pub fn new() -> LogoutRequest
Sourcepub fn meta(self, meta: impl IntoOption<Map<String, Value>>) -> LogoutRequest
pub fn meta(self, meta: impl IntoOption<Map<String, Value>>) -> LogoutRequest
The _meta property is reserved by ACP to allow clients and agents to attach additional metadata to their interactions. Implementations MUST NOT make assumptions about values at these keys.
See protocol docs: Extensibility