#[non_exhaustive]pub struct McpCapabilities {
pub http: bool,
pub sse: bool,
pub acp: bool,
pub meta: Option<Map<String, Value>>,
}Expand description
MCP capabilities supported by the agent
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.http: boolAgent supports McpServer::Http.
sse: boolAgent supports McpServer::Sse.
acp: boolunstable_mcp_over_acp only.UNSTABLE
This capability is not part of the spec yet, and may be removed or changed at any point.
Agent supports McpServer::Acp.
meta: Option<Map<String, Value>>The _meta property is reserved by ACP to allow clients and agents to attach additional metadata to their interactions. Implementations MUST NOT make assumptions about values at these keys.
See protocol docs: Extensibility
Implementations
Sourceimpl McpCapabilities
impl McpCapabilities
pub fn new() -> McpCapabilities
Sourcepub fn http(self, http: bool) -> McpCapabilities
pub fn http(self, http: bool) -> McpCapabilities
Agent supports McpServer::Http.
Sourcepub fn sse(self, sse: bool) -> McpCapabilities
pub fn sse(self, sse: bool) -> McpCapabilities
Agent supports McpServer::Sse.
Sourcepub fn acp(self, acp: bool) -> McpCapabilities
Available on crate feature unstable_mcp_over_acp only.
pub fn acp(self, acp: bool) -> McpCapabilities
unstable_mcp_over_acp only.UNSTABLE
This capability is not part of the spec yet, and may be removed or changed at any point.
Agent supports McpServer::Acp.
Sourcepub fn meta(self, meta: impl IntoOption<Map<String, Value>>) -> McpCapabilities
pub fn meta(self, meta: impl IntoOption<Map<String, Value>>) -> McpCapabilities
The _meta property is reserved by ACP to allow clients and agents to attach additional metadata to their interactions. Implementations MUST NOT make assumptions about values at these keys.
See protocol docs: Extensibility