#[non_exhaustive]pub struct PromptResponse {
pub stop_reason: StopReason,
pub usage: Option<Usage>,
pub meta: Option<Map<String, Value>>,
}Expand description
Response from processing a user prompt.
See protocol docs: Check for Completion
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.stop_reason: StopReasonIndicates why the agent stopped processing the turn.
usage: Option<Usage>unstable_end_turn_token_usage only.UNSTABLE
This capability is not part of the spec yet, and may be removed or changed at any point.
Token usage for this turn (optional).
meta: Option<Map<String, Value>>The _meta property is reserved by ACP to allow clients and agents to attach additional metadata to their interactions. Implementations MUST NOT make assumptions about values at these keys.
See protocol docs: Extensibility
Implementations
Sourceimpl PromptResponse
impl PromptResponse
pub fn new(stop_reason: StopReason) -> PromptResponse
Sourcepub fn usage(self, usage: impl IntoOption<Usage>) -> PromptResponse
Available on crate feature unstable_end_turn_token_usage only.
pub fn usage(self, usage: impl IntoOption<Usage>) -> PromptResponse
unstable_end_turn_token_usage only.UNSTABLE
This capability is not part of the spec yet, and may be removed or changed at any point.
Token usage for this turn.
Sourcepub fn meta(self, meta: impl IntoOption<Map<String, Value>>) -> PromptResponse
pub fn meta(self, meta: impl IntoOption<Map<String, Value>>) -> PromptResponse
The _meta property is reserved by ACP to allow clients and agents to attach additional metadata to their interactions. Implementations MUST NOT make assumptions about values at these keys.
See protocol docs: Extensibility