pub struct SuccessorMessage<M: JsonRpcMessage = UntypedMessage> {
pub message: M,
pub meta: Option<Value>,
}Expand description
A message being sent to the successor component.
Used in _proxy/successor when the proxy wants to forward a message downstream.
Fields
message: MThe message to be sent to the successor component.
meta: Option<Value>Optional metadata