#[non_exhaustive]pub enum SessionConfigOptionCategory {
Mode,
Model,
ModelConfig,
ThoughtLevel,
Other(String),
}Expand description
Semantic category for a session configuration option.
This is intended to help Clients distinguish broadly common selectors (e.g. model selector vs session mode selector vs thought/reasoning level) for UX purposes (keyboard shortcuts, icons, placement). It MUST NOT be required for correctness. Clients MUST handle missing or unknown categories gracefully.
Category names beginning with _ are free for custom use, like other ACP extension methods.
Category names that do not begin with _ are reserved for the ACP spec.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Mode
Session mode selector.
Model
Model selector.
ModelConfig
unstable_model_config_category only.UNSTABLE
This capability is not part of the spec yet, and may be removed or changed at any point.
Model-related configuration parameter.
ThoughtLevel
Thought/reasoning level selector.
Other(String)
Unknown / uncategorized selector.