#[non_exhaustive]pub struct BooleanConfigOptionCapabilities {
pub meta: Option<Map<String, Value>>,
}Expand description
Capabilities for boolean session configuration options.
Supplying {} means the client supports boolean session configuration options.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.meta: Option<Map<String, Value>>The _meta property is reserved by ACP to allow clients and agents to attach additional metadata to their interactions. Implementations MUST NOT make assumptions about values at these keys.
See protocol docs: Extensibility
Implementations
Sourceimpl BooleanConfigOptionCapabilities
impl BooleanConfigOptionCapabilities
Sourcepub fn new() -> BooleanConfigOptionCapabilities
pub fn new() -> BooleanConfigOptionCapabilities
Builds an empty BooleanConfigOptionCapabilities; use builder methods to advertise supported sub-capabilities.
Sourcepub fn meta(
self,
meta: impl IntoOption<Map<String, Value>>,
) -> BooleanConfigOptionCapabilities
pub fn meta( self, meta: impl IntoOption<Map<String, Value>>, ) -> BooleanConfigOptionCapabilities
The _meta property is reserved by ACP to allow clients and agents to attach additional metadata to their interactions. Implementations MUST NOT make assumptions about values at these keys.
See protocol docs: Extensibility