BooleanPropertySchema

Struct BooleanPropertySchema 

#[non_exhaustive]
pub struct BooleanPropertySchema { pub title: Option<String>, pub description: Option<String>, pub default: Option<bool>, pub meta: Option<Map<String, Value>>, }
Schema for boolean properties in an elicitation form.

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
title: Option<String>

Optional title for the property.

description: Option<String>

Human-readable description.

default: Option<bool>

Default value.

meta: Option<Map<String, Value>>

The _meta property is reserved by ACP to allow clients and agents to attach additional metadata to their interactions. Implementations MUST NOT make assumptions about values at these keys.

See protocol docs: Extensibility

Implementations

Source

impl BooleanPropertySchema

pub fn new() -> BooleanPropertySchema

Create a new boolean property schema.

pub fn title(self, title: impl IntoOption<String>) -> BooleanPropertySchema

Optional title for the property.

pub fn description( self, description: impl IntoOption<String>, ) -> BooleanPropertySchema

Human-readable description.

pub fn default_value( self, default: impl IntoOption<bool>, ) -> BooleanPropertySchema

Default value.

pub fn meta( self, meta: impl IntoOption<Map<String, Value>>, ) -> BooleanPropertySchema

The _meta property is reserved by ACP to allow clients and agents to attach additional metadata to their interactions. Implementations MUST NOT make assumptions about values at these keys.

See protocol docs: Extensibility