ElicitationSchema

Struct ElicitationSchema 

#[non_exhaustive]
pub struct ElicitationSchema { pub type_: ElicitationSchemaType, pub title: Option<String>, pub properties: BTreeMap<String, ElicitationPropertySchema>, pub required: Option<Vec<String>>, pub description: Option<String>, pub meta: Option<Map<String, Value>>, }
Type-safe elicitation schema for requesting structured user input.

This represents a JSON Schema object with primitive-typed properties, as required by the elicitation specification.

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
type_: ElicitationSchemaType

Type discriminator. Always "object".

title: Option<String>

Optional title for the schema.

properties: BTreeMap<String, ElicitationPropertySchema>

Property definitions (must be primitive types).

required: Option<Vec<String>>

List of required property names.

description: Option<String>

Optional description of what this schema represents.

meta: Option<Map<String, Value>>

The _meta property is reserved by ACP to allow clients and agents to attach additional metadata to their interactions. Implementations MUST NOT make assumptions about values at these keys.

See protocol docs: Extensibility

Implementations

Source

impl ElicitationSchema

pub fn new() -> ElicitationSchema

Create a new empty elicitation schema.

pub fn title(self, title: impl IntoOption<String>) -> ElicitationSchema

Optional title for the schema.

pub fn description( self, description: impl IntoOption<String>, ) -> ElicitationSchema

Optional description of what this schema represents.

pub fn meta( self, meta: impl IntoOption<Map<String, Value>>, ) -> ElicitationSchema

The _meta property is reserved by ACP to allow clients and agents to attach additional metadata to their interactions. Implementations MUST NOT make assumptions about values at these keys.

See protocol docs: Extensibility

pub fn property<S>( self, name: impl Into<String>, schema: S, required: bool, ) -> ElicitationSchema

Add a property to the schema.

pub fn string( self, name: impl Into<String>, required: bool, ) -> ElicitationSchema

Add a string property.

pub fn email(self, name: impl Into<String>, required: bool) -> ElicitationSchema

Add an email property.

pub fn uri(self, name: impl Into<String>, required: bool) -> ElicitationSchema

Add a URI property.

pub fn date(self, name: impl Into<String>, required: bool) -> ElicitationSchema

Add a date property.

pub fn date_time( self, name: impl Into<String>, required: bool, ) -> ElicitationSchema

Add a date-time property.

pub fn number( self, name: impl Into<String>, min: f64, max: f64, required: bool, ) -> ElicitationSchema

Add a number property with range.

pub fn integer( self, name: impl Into<String>, min: i64, max: i64, required: bool, ) -> ElicitationSchema

Add an integer property with range.

pub fn boolean( self, name: impl Into<String>, required: bool, ) -> ElicitationSchema

Add a boolean property.