#[non_exhaustive]pub struct EmbeddedResource {
pub annotations: Option<Annotations>,
pub resource: EmbeddedResourceResource,
pub meta: Option<Map<String, Value>>,
}Expand description
The contents of a resource, embedded into a prompt or tool call result.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.annotations: Option<Annotations>Optional annotations that help clients decide how to display or route this content.
resource: EmbeddedResourceResourceEmbedded resource payload, either text or binary data.
meta: Option<Map<String, Value>>The _meta property is reserved by ACP to allow clients and agents to attach additional metadata to their interactions. Implementations MUST NOT make assumptions about values at these keys.
See protocol docs: Extensibility
Implementations
Sourceimpl EmbeddedResource
impl EmbeddedResource
Sourcepub fn new(resource: EmbeddedResourceResource) -> EmbeddedResource
pub fn new(resource: EmbeddedResourceResource) -> EmbeddedResource
Builds EmbeddedResource with its required content payload; optional annotations and metadata start unset.
Sourcepub fn annotations(
self,
annotations: impl IntoOption<Annotations>,
) -> EmbeddedResource
pub fn annotations( self, annotations: impl IntoOption<Annotations>, ) -> EmbeddedResource
Sets or clears the optional annotations field.
Sourcepub fn meta(self, meta: impl IntoOption<Map<String, Value>>) -> EmbeddedResource
pub fn meta(self, meta: impl IntoOption<Map<String, Value>>) -> EmbeddedResource
The _meta property is reserved by ACP to allow clients and agents to attach additional metadata to their interactions. Implementations MUST NOT make assumptions about values at these keys.
See protocol docs: Extensibility