#[non_exhaustive]pub struct LoadSessionResponse {
pub modes: Option<SessionModeState>,
pub config_options: Option<Vec<SessionConfigOption>>,
pub meta: Option<Map<String, Value>>,
}Expand description
Response from loading an existing session.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.modes: Option<SessionModeState>Initial mode state if supported by the Agent
See protocol docs: Session Modes
config_options: Option<Vec<SessionConfigOption>>Initial session configuration options if supported by the Agent.
meta: Option<Map<String, Value>>The _meta property is reserved by ACP to allow clients and agents to attach additional metadata to their interactions. Implementations MUST NOT make assumptions about values at these keys.
See protocol docs: Extensibility
Implementations
Sourceimpl LoadSessionResponse
impl LoadSessionResponse
Sourcepub fn new() -> LoadSessionResponse
pub fn new() -> LoadSessionResponse
Builds LoadSessionResponse with the required response fields set; optional fields start unset or empty.
Sourcepub fn modes(
self,
modes: impl IntoOption<SessionModeState>,
) -> LoadSessionResponse
pub fn modes( self, modes: impl IntoOption<SessionModeState>, ) -> LoadSessionResponse
Initial mode state if supported by the Agent
See protocol docs: Session Modes
Sourcepub fn config_options(
self,
config_options: impl IntoOption<Vec<SessionConfigOption>>,
) -> LoadSessionResponse
pub fn config_options( self, config_options: impl IntoOption<Vec<SessionConfigOption>>, ) -> LoadSessionResponse
Initial session configuration options if supported by the Agent.
Sourcepub fn meta(
self,
meta: impl IntoOption<Map<String, Value>>,
) -> LoadSessionResponse
pub fn meta( self, meta: impl IntoOption<Map<String, Value>>, ) -> LoadSessionResponse
The _meta property is reserved by ACP to allow clients and agents to attach additional metadata to their interactions. Implementations MUST NOT make assumptions about values at these keys.
See protocol docs: Extensibility