#[non_exhaustive]pub struct McpRequestId(pub Arc<str>);Available on crate feature
unstable_mcp_over_acp only.Expand description
UNSTABLE
This capability is not part of the spec yet, and may be removed or changed at any point.
Identifies an inner MCP request active against a server on this ACP connection.
Generated by the caller and preserved unchanged by proxies. This is distinct from the outer ACP JSON-RPC request ID.
Tuple Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.0: Arc<str>Implementations
Sourceimpl McpRequestId
impl McpRequestId
Sourcepub fn new(id: impl Into<Arc<str>>) -> McpRequestId
pub fn new(id: impl Into<Arc<str>>) -> McpRequestId
Wraps a protocol string as a typed McpRequestId.