#[non_exhaustive]pub struct NumberPropertySchema {
pub title: Option<String>,
pub description: Option<String>,
pub minimum: Option<f64>,
pub maximum: Option<f64>,
pub default: Option<f64>,
pub meta: Option<Map<String, Value>>,
}Expand description
Schema for number (floating-point) properties in an elicitation form.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.title: Option<String>Optional title for the property.
description: Option<String>Human-readable description.
minimum: Option<f64>Minimum value (inclusive).
maximum: Option<f64>Maximum value (inclusive).
default: Option<f64>Default value.
meta: Option<Map<String, Value>>The _meta property is reserved by ACP to allow clients and agents to attach additional metadata to their interactions. Implementations MUST NOT make assumptions about values at these keys.
See protocol docs: Extensibility
Implementations
Sourceimpl NumberPropertySchema
impl NumberPropertySchema
Sourcepub fn new() -> NumberPropertySchema
pub fn new() -> NumberPropertySchema
Create a new number property schema.
Sourcepub fn title(self, title: impl IntoOption<String>) -> NumberPropertySchema
pub fn title(self, title: impl IntoOption<String>) -> NumberPropertySchema
Optional title for the property.
Sourcepub fn description(
self,
description: impl IntoOption<String>,
) -> NumberPropertySchema
pub fn description( self, description: impl IntoOption<String>, ) -> NumberPropertySchema
Human-readable description.
Sourcepub fn minimum(self, minimum: impl IntoOption<f64>) -> NumberPropertySchema
pub fn minimum(self, minimum: impl IntoOption<f64>) -> NumberPropertySchema
Minimum value (inclusive).
Sourcepub fn maximum(self, maximum: impl IntoOption<f64>) -> NumberPropertySchema
pub fn maximum(self, maximum: impl IntoOption<f64>) -> NumberPropertySchema
Maximum value (inclusive).
Sourcepub fn default_value(
self,
default: impl IntoOption<f64>,
) -> NumberPropertySchema
pub fn default_value( self, default: impl IntoOption<f64>, ) -> NumberPropertySchema
Default value.
Sourcepub fn meta(
self,
meta: impl IntoOption<Map<String, Value>>,
) -> NumberPropertySchema
pub fn meta( self, meta: impl IntoOption<Map<String, Value>>, ) -> NumberPropertySchema
The _meta property is reserved by ACP to allow clients and agents to attach additional metadata to their interactions. Implementations MUST NOT make assumptions about values at these keys.
See protocol docs: Extensibility