OtherStopReason

Struct OtherStopReason 

#[non_exhaustive]
pub struct OtherStopReason { pub stop_reason: String, pub fields: BTreeMap<String, Value>, }
Available on crate feature unstable_subagents only.
UNSTABLE

This capability is not part of the spec yet, and may be removed or changed at any point.

Custom or future stop reason payload, preserving its discriminator and fields.

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
stop_reason: String

Unrecognized stop reason.

fields: BTreeMap<String, Value>

Remaining fields of the unknown stop reason.

Implementations

Source

impl OtherStopReason

pub fn new( stop_reason: impl Into<String>, fields: BTreeMap<String, Value>, ) -> OtherStopReason

Builds a custom stop reason, preserving its extension fields.