SubagentCapabilities

Struct SubagentCapabilities 

#[non_exhaustive]
pub struct SubagentCapabilities { pub meta: Option<Map<String, Value>>, }
UNSTABLE

This capability is not part of the spec yet, and may be removed or changed at any point.

Capability marker for exposing reusable child sessions as restricted ACP sessions.

Supplying {} advertises support for child association and state updates, session-directed messages, and restricted-session semantics. The client must advertise this capability before the agent sends subagent updates or session-directed messages.

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
meta: Option<Map<String, Value>>

The _meta property is reserved by ACP to allow clients and agents to attach additional metadata to their interactions. Implementations MUST NOT make assumptions about values at these keys.

Implementations

Source

impl SubagentCapabilities

pub fn new() -> SubagentCapabilities

Available on crate feature unstable_subagents only.

Builds an empty capability marker.

pub fn meta( self, meta: impl IntoOption<Map<String, Value>>, ) -> SubagentCapabilities

Available on crate feature unstable_subagents only.

The _meta property is reserved by ACP to allow clients and agents to attach additional metadata to their interactions. Implementations MUST NOT make assumptions about values at these keys.