ElicitationAction

Enum ElicitationAction 

#[non_exhaustive]
pub enum ElicitationAction { Accept(ElicitationAcceptAction), Decline, Cancel, }
Available on crate feature unstable_protocol_v2 only.
UNSTABLE

This capability is not part of the spec yet, and may be removed or changed at any point.

The user’s action in response to an elicitation.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


Accept(ElicitationAcceptAction)

The user accepted and provided content.



Decline

The user declined the elicitation.



Cancel

The elicitation was cancelled.