ElicitationMode

Enum ElicitationMode 

#[non_exhaustive]
pub enum ElicitationMode { Form(ElicitationFormMode), Url(ElicitationUrlMode), }
Available on crate feature unstable_protocol_v2 only.
UNSTABLE

This capability is not part of the spec yet, and may be removed or changed at any point.

The mode of elicitation, determining how user input is collected.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


Form(ElicitationFormMode)

Form-based elicitation where the client renders a form from the provided schema.



Url(ElicitationUrlMode)

URL-based elicitation where the client directs the user to a URL.

Implementations

Source

impl ElicitationMode

pub fn scope(&self) -> &ElicitationScope

Returns the scope this elicitation mode is tied to.