#[non_exhaustive]pub enum McpServer {
Http(McpServerHttp),
Acp(McpServerAcp),
Stdio(McpServerStdio),
Other(OtherMcpServer),
}unstable_protocol_v2 only.Expand description
Configuration for connecting to an MCP (Model Context Protocol) server.
MCP servers provide tools and context that the agent can use when processing prompts.
See protocol docs: MCP Servers
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Http(McpServerHttp)
HTTP transport configuration
Only available when the Agent capabilities include mcp.http.
Acp(McpServerAcp)
unstable_mcp_over_acp only.UNSTABLE
This capability is not part of the spec yet, and may be removed or changed at any point.
ACP transport configuration
Only available when the Agent capabilities include mcp.acp.
The MCP server is provided by an ACP component and communicates over the ACP channel.
Stdio(McpServerStdio)
Stdio transport configuration
Only available when the Agent capabilities include mcp.stdio.
Other(OtherMcpServer)
Custom or future MCP server transport configuration.
Values beginning with _ are reserved for implementation-specific
extensions. Unknown values that do not begin with _ are reserved for
future ACP variants.
Receivers that do not understand this transport should preserve the raw payload when storing, replaying, proxying, or forwarding session setup data, and otherwise ignore it or reject the server configuration.