#[non_exhaustive]pub enum PlanUpdateContent {
Items(PlanItems),
Other(OtherPlanUpdateContent),
}Available on crate feature
unstable_protocol_v2 only.Expand description
Updated content for a plan.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Items(PlanItems)
Structured plan entries.
Other(OtherPlanUpdateContent)
Custom or future plan update content.
Values beginning with _ are reserved for implementation-specific
extensions. Unknown values that do not begin with _ are reserved for
future ACP variants.
Receivers that do not understand this content type should preserve the raw payload when storing, replaying, proxying, or forwarding plans, and otherwise ignore it or display it generically.
Implementations