#[non_exhaustive]pub enum RequestPermissionSubject {
ToolCall(Box<ToolCallPermissionSubject>),
Other(OtherRequestPermissionSubject),
}Available on crate feature
unstable_protocol_v2 only.Expand description
The operation requiring permission.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
ToolCall(Box<ToolCallPermissionSubject>)
Permission is requested before executing a tool call.
Other(OtherRequestPermissionSubject)
Custom or future permission subject.
Values beginning with _ are reserved for implementation-specific
extensions. Unknown values that do not begin with _ are reserved for
future ACP variants.
Clients that do not understand this subject type should preserve the raw payload when storing, replaying, proxying, or forwarding permission requests, and otherwise display a generic permission prompt or decline it according to policy.