SessionConfigKind

Enum SessionConfigKind 

#[non_exhaustive]
pub enum SessionConfigKind { Select(SessionConfigSelect), Boolean(SessionConfigBoolean), Other(OtherSessionConfigKind), }
Available on crate feature unstable_protocol_v2 only.
Type-specific session configuration option payload.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


Select(SessionConfigSelect)

Single-value selector (dropdown).



Boolean(SessionConfigBoolean)

Available on crate feature unstable_boolean_config only.

UNSTABLE

This capability is not part of the spec yet, and may be removed or changed at any point.

Boolean on/off toggle.



Other(OtherSessionConfigKind)

Custom or future session configuration option payload.

Values beginning with _ are reserved for implementation-specific extensions. Unknown values that do not begin with _ are reserved for future ACP variants.

Clients that do not understand this option type should preserve the raw payload when storing, replaying, proxying, or forwarding configuration data, and otherwise ignore the option or display it generically.