SessionUpdate

Enum SessionUpdate 

#[non_exhaustive]
pub enum SessionUpdate { UserMessageChunk(ContentChunk), AgentMessageChunk(ContentChunk), AgentThoughtChunk(ContentChunk), ToolCall(ToolCall), ToolCallUpdate(ToolCallUpdate), PlanUpdate(PlanUpdate), AvailableCommandsUpdate(AvailableCommandsUpdate), ConfigOptionUpdate(ConfigOptionUpdate), SessionInfoUpdate(SessionInfoUpdate), UsageUpdate(UsageUpdate), Other(OtherSessionUpdate), }
Available on crate feature unstable_protocol_v2 only.
Different types of updates that can be sent during session processing.

These updates provide real-time feedback about the agent’s progress.

See protocol docs: Agent Reports Output

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


UserMessageChunk(ContentChunk)

A chunk of the user’s message being streamed.



AgentMessageChunk(ContentChunk)

A chunk of the agent’s response being streamed.



AgentThoughtChunk(ContentChunk)

A chunk of the agent’s internal reasoning being streamed.



ToolCall(ToolCall)

Notification that a new tool call has been initiated.



ToolCallUpdate(ToolCallUpdate)

Update on the status or results of a tool call.



PlanUpdate(PlanUpdate)

A content update for a plan identified by ID. See protocol docs: Agent Plan



AvailableCommandsUpdate(AvailableCommandsUpdate)

Available commands are ready or have changed



ConfigOptionUpdate(ConfigOptionUpdate)

Session configuration options have been updated.



SessionInfoUpdate(SessionInfoUpdate)

Session metadata has been updated (title, timestamps, custom metadata)



UsageUpdate(UsageUpdate)

Context window and cost update for the session.



Other(OtherSessionUpdate)

Custom or future session update.

Values beginning with _ are reserved for implementation-specific extensions. Unknown values that do not begin with _ are reserved for future ACP variants.

Receivers that do not understand this update type should preserve the raw payload when storing, replaying, proxying, or forwarding session history, and otherwise ignore it or display it generically.