#[non_exhaustive]pub enum StateUpdate {
Running(RunningStateUpdate),
Idle(IdleStateUpdate),
RequiresAction(RequiresActionStateUpdate),
Other(OtherStateUpdate),
}Available on crate feature
unstable_protocol_v2 only.Expand description
The agent’s session state has changed.
This update is the mechanism for reporting session activity transitions.
A session/prompt response only acknowledges that the prompt was accepted;
agents use state_update notifications to report that processing has started,
that the session is idle, or that progress is blocked on user action.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Running(RunningStateUpdate)
The agent is actively processing work in the session.
Idle(IdleStateUpdate)
The agent is not currently processing work in the session.
RequiresAction(RequiresActionStateUpdate)
The agent is waiting on user action before it can continue.
Other(OtherStateUpdate)
Custom or future session state.
Values beginning with _ are reserved for implementation-specific
extensions. Unknown values that do not begin with _ are reserved for
future ACP variants.