#[non_exhaustive]pub struct AgentMessage {
pub message_id: MessageId,
pub content: MaybeUndefined<Vec<ContentBlock>>,
pub meta: MaybeUndefined<Map<String, Value>>,
}unstable_protocol_v2 only.Expand description
An agent message upsert.
Only AgentMessage::message_id is required. Other fields have patch
semantics: omitted fields leave the existing message value unchanged, null
clears or unsets the value, and concrete values replace the previous value.
For a new messageId, omitted fields use client defaults. content is
replaced as a whole array; send [] or null to clear it.
Message updates and chunks are applied in the order they are received. When
an agent_message update includes content, that array replaces any
content previously accumulated for the message, including content from
earlier chunks. Later chunks with the same messageId append to the current
content.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.message_id: MessageIdA unique identifier for the message.
content: MaybeUndefined<Vec<ContentBlock>>Complete replacement content for this message.
meta: MaybeUndefined<Map<String, Value>>The _meta property is reserved by ACP to allow clients and agents to attach additional metadata to their interactions. Implementations MUST NOT make assumptions about values at these keys.
See protocol docs: Extensibility
Implementations
Sourceimpl AgentMessage
impl AgentMessage
Sourcepub fn new(message_id: impl Into<MessageId>) -> AgentMessage
pub fn new(message_id: impl Into<MessageId>) -> AgentMessage
Builds AgentMessage with the required fields set; optional fields start unset or empty.
Sourcepub fn content(
self,
content: impl IntoMaybeUndefined<Vec<ContentBlock>>,
) -> AgentMessage
pub fn content( self, content: impl IntoMaybeUndefined<Vec<ContentBlock>>, ) -> AgentMessage
Complete replacement content for this message.
Sourcepub fn meta(
self,
meta: impl IntoMaybeUndefined<Map<String, Value>>,
) -> AgentMessage
pub fn meta( self, meta: impl IntoMaybeUndefined<Map<String, Value>>, ) -> AgentMessage
The _meta property is reserved by ACP to allow clients and agents to attach additional metadata to their interactions. Implementations MUST NOT make assumptions about values at these keys.
See protocol docs: Extensibility