AuthMethodTerminal

Struct AuthMethodTerminal 

#[non_exhaustive]
pub struct AuthMethodTerminal { pub id: AuthMethodId, pub name: String, pub description: Option<String>, pub args: Vec<String>, pub env: HashMap<String, String>, pub meta: Option<Map<String, Value>>, }
Available on crate feature unstable_protocol_v2 only.
UNSTABLE

This capability is not part of the spec yet, and may be removed or changed at any point.

Terminal-based authentication method.

The client runs an interactive terminal for the user to authenticate via a TUI.

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
id: AuthMethodId

Unique identifier for this authentication method.

name: String

Human-readable name of the authentication method.

description: Option<String>

Optional description providing more details about this authentication method.

args: Vec<String>

Additional arguments to pass when running the agent binary for terminal auth.

env: HashMap<String, String>

Additional environment variables to set when running the agent binary for terminal auth.

meta: Option<Map<String, Value>>

The _meta property is reserved by ACP to allow clients and agents to attach additional metadata to their interactions. Implementations MUST NOT make assumptions about values at these keys.

See protocol docs: Extensibility

Implementations

Source

impl AuthMethodTerminal

pub fn new( id: impl Into<AuthMethodId>, name: impl Into<String>, ) -> AuthMethodTerminal

Available on crate feature unstable_auth_methods only.
pub fn args(self, args: Vec<String>) -> AuthMethodTerminal

Available on crate feature unstable_auth_methods only.

Additional arguments to pass when running the agent binary for terminal auth.

pub fn env(self, env: HashMap<String, String>) -> AuthMethodTerminal

Available on crate feature unstable_auth_methods only.

Additional environment variables to set when running the agent binary for terminal auth.

pub fn description( self, description: impl IntoOption<String>, ) -> AuthMethodTerminal

Available on crate feature unstable_auth_methods only.

Optional description providing more details about this authentication method.

pub fn meta( self, meta: impl IntoOption<Map<String, Value>>, ) -> AuthMethodTerminal

Available on crate feature unstable_auth_methods only.

The _meta property is reserved by ACP to allow clients and agents to attach additional metadata to their interactions. Implementations MUST NOT make assumptions about values at these keys.

See protocol docs: Extensibility