#[non_exhaustive]pub struct BlobResourceContents {
pub blob: String,
pub mime_type: Option<String>,
pub uri: String,
pub meta: Option<Map<String, Value>>,
}unstable_protocol_v2 only.Expand description
Binary resource contents.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.blob: StringBase64-encoded bytes for a binary resource payload.
mime_type: Option<String>MIME type describing the encoded media payload.
uri: StringURI associated with this resource or media payload.
meta: Option<Map<String, Value>>The _meta property is reserved by ACP to allow clients and agents to attach additional metadata to their interactions. Implementations MUST NOT make assumptions about values at these keys.
See protocol docs: Extensibility
Implementations
Sourceimpl BlobResourceContents
impl BlobResourceContents
Sourcepub fn new(
blob: impl Into<String>,
uri: impl Into<String>,
) -> BlobResourceContents
pub fn new( blob: impl Into<String>, uri: impl Into<String>, ) -> BlobResourceContents
Builds BlobResourceContents with its required content payload; optional annotations and metadata start unset.
Sourcepub fn mime_type(
self,
mime_type: impl IntoOption<String>,
) -> BlobResourceContents
pub fn mime_type( self, mime_type: impl IntoOption<String>, ) -> BlobResourceContents
Sets or clears the optional mimeType field.
Sourcepub fn meta(
self,
meta: impl IntoOption<Map<String, Value>>,
) -> BlobResourceContents
pub fn meta( self, meta: impl IntoOption<Map<String, Value>>, ) -> BlobResourceContents
The _meta property is reserved by ACP to allow clients and agents to attach additional metadata to their interactions. Implementations MUST NOT make assumptions about values at these keys.
See protocol docs: Extensibility