#[non_exhaustive]pub struct BooleanPropertySchema {
pub title: Option<String>,
pub description: Option<String>,
pub default: Option<bool>,
pub meta: Option<Map<String, Value>>,
}unstable_protocol_v2 only.Expand description
Schema for boolean properties in an elicitation form.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.title: Option<String>Optional title for the property.
Optional. Omitted and null are equivalent and mean no title is provided.
description: Option<String>Human-readable description.
Optional. Omitted and null are equivalent and mean no description is provided.
default: Option<bool>Default value.
Optional. Omitted and null are equivalent and mean no default value is provided.
meta: Option<Map<String, Value>>The _meta property is reserved by ACP to allow clients and agents to attach additional metadata to their interactions. Implementations MUST NOT make assumptions about values at these keys.
Optional. Omitted and null are equivalent and mean no metadata.
See protocol docs: Extensibility
Implementations
Sourceimpl BooleanPropertySchema
impl BooleanPropertySchema
Sourcepub fn new() -> BooleanPropertySchema
pub fn new() -> BooleanPropertySchema
Create a new boolean property schema.
Sourcepub fn title(self, title: impl IntoOption<String>) -> BooleanPropertySchema
pub fn title(self, title: impl IntoOption<String>) -> BooleanPropertySchema
Optional title for the property.
Sourcepub fn description(
self,
description: impl IntoOption<String>,
) -> BooleanPropertySchema
pub fn description( self, description: impl IntoOption<String>, ) -> BooleanPropertySchema
Human-readable description.
Sourcepub fn default_value(
self,
default: impl IntoOption<bool>,
) -> BooleanPropertySchema
pub fn default_value( self, default: impl IntoOption<bool>, ) -> BooleanPropertySchema
Default value.
Sourcepub fn meta(
self,
meta: impl IntoOption<Map<String, Value>>,
) -> BooleanPropertySchema
pub fn meta( self, meta: impl IntoOption<Map<String, Value>>, ) -> BooleanPropertySchema
The _meta property is reserved by ACP to allow clients and agents to attach additional metadata to their interactions. Implementations MUST NOT make assumptions about values at these keys.
Optional. Omitted and null are equivalent and mean no metadata.
See protocol docs: Extensibility