#[non_exhaustive]pub struct CancelRequestNotification {
pub request_id: RequestId,
pub meta: Option<Map<String, Value>>,
}Available on crate feature
unstable_protocol_v2 only.Expand description
Notification to cancel an ongoing request.
See protocol docs: Cancellation
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.request_id: RequestIdThe ID of the request to cancel.
meta: Option<Map<String, Value>>The _meta property is reserved by ACP to allow clients and agents to attach additional metadata to their interactions. Implementations MUST NOT make assumptions about values at these keys.
See protocol docs: Extensibility
Implementations
Sourceimpl CancelRequestNotification
impl CancelRequestNotification
Sourcepub fn new(request_id: impl Into<RequestId>) -> CancelRequestNotification
pub fn new(request_id: impl Into<RequestId>) -> CancelRequestNotification
Builds CancelRequestNotification with the required notification fields set; optional fields start unset or empty.
Sourcepub fn meta(
self,
meta: impl IntoOption<Map<String, Value>>,
) -> CancelRequestNotification
pub fn meta( self, meta: impl IntoOption<Map<String, Value>>, ) -> CancelRequestNotification
The _meta property is reserved by ACP to allow clients and agents to attach additional metadata to their interactions. Implementations MUST NOT make assumptions about values at these keys.
See protocol docs: Extensibility