#[non_exhaustive]pub struct CancelSessionNotification {
pub session_id: SessionId,
pub meta: Option<Map<String, Value>>,
}Available on crate feature
unstable_protocol_v2 only.Expand description
Notification to cancel ongoing operations for a session.
See protocol docs: Cancellation
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.session_id: SessionIdThe ID of the session to cancel operations for.
meta: Option<Map<String, Value>>The _meta property is reserved by ACP to allow clients and agents to attach additional metadata to their interactions. Implementations MUST NOT make assumptions about values at these keys.
See protocol docs: Extensibility
Implementations
Sourceimpl CancelSessionNotification
impl CancelSessionNotification
Sourcepub fn new(session_id: impl Into<SessionId>) -> CancelSessionNotification
pub fn new(session_id: impl Into<SessionId>) -> CancelSessionNotification
Builds CancelSessionNotification with the required notification fields set; optional fields start unset or empty.
Sourcepub fn meta(
self,
meta: impl IntoOption<Map<String, Value>>,
) -> CancelSessionNotification
pub fn meta( self, meta: impl IntoOption<Map<String, Value>>, ) -> CancelSessionNotification
The _meta property is reserved by ACP to allow clients and agents to attach additional metadata to their interactions. Implementations MUST NOT make assumptions about values at these keys.
See protocol docs: Extensibility