#[non_exhaustive]pub struct CloseSessionRequest {
pub session_id: SessionId,
pub meta: Option<Map<String, Value>>,
}unstable_protocol_v2 only.Expand description
Request parameters for closing an active session.
If supported, the agent must cancel any ongoing work related to the session
(treat it as if session/cancel was called) and then free up any resources
associated with the session.
Only available if the Agent supports the session.close capability.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.session_id: SessionIdThe ID of the session to close.
meta: Option<Map<String, Value>>The _meta property is reserved by ACP to allow clients and agents to attach additional metadata to their interactions. Implementations MUST NOT make assumptions about values at these keys.
See protocol docs: Extensibility
Implementations
Sourceimpl CloseSessionRequest
impl CloseSessionRequest
Sourcepub fn new(session_id: impl Into<SessionId>) -> CloseSessionRequest
pub fn new(session_id: impl Into<SessionId>) -> CloseSessionRequest
Builds CloseSessionRequest with the required request fields set; optional fields start unset or empty.
Sourcepub fn meta(
self,
meta: impl IntoOption<Map<String, Value>>,
) -> CloseSessionRequest
pub fn meta( self, meta: impl IntoOption<Map<String, Value>>, ) -> CloseSessionRequest
The _meta property is reserved by ACP to allow clients and agents to attach additional metadata to their interactions. Implementations MUST NOT make assumptions about values at these keys.
See protocol docs: Extensibility