#[non_exhaustive]pub struct ConnectMcpRequest {
pub acp_id: McpServerAcpId,
pub meta: Option<Map<String, Value>>,
}Available on crate feature
unstable_protocol_v2 only.Expand description
UNSTABLE
This capability is not part of the spec yet, and may be removed or changed at any point.
Request parameters for mcp/connect.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.acp_id: McpServerAcpIdThe ACP MCP server ID that was provided by the component declaring the MCP server.
meta: Option<Map<String, Value>>The _meta property is reserved by ACP to allow clients and agents to attach additional metadata to their interactions. Implementations MUST NOT make assumptions about values at these keys.
See protocol docs: Extensibility
Implementations
Sourceimpl ConnectMcpRequest
impl ConnectMcpRequest
pub fn new(acp_id: impl Into<McpServerAcpId>) -> ConnectMcpRequest
Sourcepub fn meta(
self,
meta: impl IntoOption<Map<String, Value>>,
) -> ConnectMcpRequest
pub fn meta( self, meta: impl IntoOption<Map<String, Value>>, ) -> ConnectMcpRequest
The _meta property is reserved by ACP to allow clients and agents to attach additional metadata to their interactions. Implementations MUST NOT make assumptions about values at these keys.
See protocol docs: Extensibility