#[non_exhaustive]pub struct Cost {
pub amount: f64,
pub currency: String,
pub meta: Option<Map<String, Value>>,
}Available on crate feature
unstable_protocol_v2 only.Expand description
Cost information for a session.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.amount: f64Total cumulative cost for session.
currency: StringISO 4217 currency code (e.g., “USD”, “EUR”).
meta: Option<Map<String, Value>>The _meta property is reserved by ACP to allow clients and agents to attach additional metadata to their interactions. Implementations MUST NOT make assumptions about values at these keys.
See protocol docs: Extensibility
Implementations
Sourceimpl Cost
impl Cost
Sourcepub fn new(amount: f64, currency: impl Into<String>) -> Cost
pub fn new(amount: f64, currency: impl Into<String>) -> Cost
Builds Cost with the required fields set; optional fields start unset or empty.
Sourcepub fn meta(self, meta: impl IntoOption<Map<String, Value>>) -> Cost
pub fn meta(self, meta: impl IntoOption<Map<String, Value>>) -> Cost
The _meta property is reserved by ACP to allow clients and agents to attach additional metadata to their interactions. Implementations MUST NOT make assumptions about values at these keys.
See protocol docs: Extensibility