#[non_exhaustive]pub struct DeleteSessionRequest {
pub session_id: SessionId,
pub meta: Option<Map<String, Value>>,
}Available on crate feature
unstable_protocol_v2 only.Expand description
Request parameters for deleting an existing session from session/list.
Only available if the Agent supports the session.delete capability.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.session_id: SessionIdThe ID of the session to delete.
meta: Option<Map<String, Value>>The _meta property is reserved by ACP to allow clients and agents to attach additional metadata to their interactions. Implementations MUST NOT make assumptions about values at these keys.
See protocol docs: Extensibility
Implementations
Sourceimpl DeleteSessionRequest
impl DeleteSessionRequest
pub fn new(session_id: impl Into<SessionId>) -> DeleteSessionRequest
Sourcepub fn meta(
self,
meta: impl IntoOption<Map<String, Value>>,
) -> DeleteSessionRequest
pub fn meta( self, meta: impl IntoOption<Map<String, Value>>, ) -> DeleteSessionRequest
The _meta property is reserved by ACP to allow clients and agents to attach additional metadata to their interactions. Implementations MUST NOT make assumptions about values at these keys.
See protocol docs: Extensibility