#[non_exhaustive]pub struct ElicitationRequestScope {
pub request_id: RequestId,
}Available on crate feature
unstable_protocol_v2 only.Expand description
UNSTABLE
This capability is not part of the spec yet, and may be removed or changed at any point.
Request-scoped elicitation, tied to a specific JSON-RPC request outside of a session (e.g., during auth/configuration phases before any session is started).
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.request_id: RequestIdThe request this elicitation is tied to.
Implementations
Sourceimpl ElicitationRequestScope
impl ElicitationRequestScope
pub fn new(request_id: impl Into<RequestId>) -> ElicitationRequestScope