IdleStateUpdate

Struct IdleStateUpdate 

#[non_exhaustive]
pub struct IdleStateUpdate { pub stop_reason: Option<StopReason>, pub usage: Option<Usage>, pub meta: Option<Map<String, Value>>, }
Available on crate feature unstable_protocol_v2 only.
The agent is not currently processing work in the session.

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
stop_reason: Option<StopReason>

Indicates why the agent stopped processing active session work.

Optional. Omitted or null both mean the agent is not reporting a stop reason. Agents SHOULD include this when the idle transition ends active work.

usage: Option<Usage>
Available on crate feature unstable_end_turn_token_usage only.

UNSTABLE

This capability is not part of the spec yet, and may be removed or changed at any point.

Token usage for completed session work.

Optional. Omitted or null both mean the agent is not reporting token usage for this state update.

meta: Option<Map<String, Value>>

The _meta property is reserved by ACP to allow clients and agents to attach additional metadata to their interactions. Implementations MUST NOT make assumptions about values at these keys.

See protocol docs: Extensibility

Implementations

Source

impl IdleStateUpdate

pub fn new() -> IdleStateUpdate

Builds IdleStateUpdate with the required fields set; optional fields start unset or empty.

pub fn stop_reason( self, stop_reason: impl IntoOption<StopReason>, ) -> IdleStateUpdate

Indicates why the agent stopped processing active session work.

pub fn usage(self, usage: impl IntoOption<Usage>) -> IdleStateUpdate

Available on crate feature unstable_end_turn_token_usage only.

UNSTABLE

This capability is not part of the spec yet, and may be removed or changed at any point.

Token usage for completed session work.

pub fn meta(self, meta: impl IntoOption<Map<String, Value>>) -> IdleStateUpdate

The _meta property is reserved by ACP to allow clients and agents to attach additional metadata to their interactions. Implementations MUST NOT make assumptions about values at these keys.

See protocol docs: Extensibility