#[non_exhaustive]pub struct IntegerPropertySchema {
pub title: Option<String>,
pub description: Option<String>,
pub minimum: Option<i64>,
pub maximum: Option<i64>,
pub default: Option<i64>,
pub meta: Option<Map<String, Value>>,
}unstable_protocol_v2 only.Expand description
Schema for integer properties in an elicitation form.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.title: Option<String>Optional title for the property.
description: Option<String>Human-readable description.
minimum: Option<i64>Minimum value (inclusive).
maximum: Option<i64>Maximum value (inclusive).
default: Option<i64>Default value.
meta: Option<Map<String, Value>>The _meta property is reserved by ACP to allow clients and agents to attach additional metadata to their interactions. Implementations MUST NOT make assumptions about values at these keys.
See protocol docs: Extensibility
Implementations
Sourceimpl IntegerPropertySchema
impl IntegerPropertySchema
Sourcepub fn new() -> IntegerPropertySchema
pub fn new() -> IntegerPropertySchema
Create a new integer property schema.
Sourcepub fn title(self, title: impl IntoOption<String>) -> IntegerPropertySchema
pub fn title(self, title: impl IntoOption<String>) -> IntegerPropertySchema
Optional title for the property.
Sourcepub fn description(
self,
description: impl IntoOption<String>,
) -> IntegerPropertySchema
pub fn description( self, description: impl IntoOption<String>, ) -> IntegerPropertySchema
Human-readable description.
Sourcepub fn minimum(self, minimum: impl IntoOption<i64>) -> IntegerPropertySchema
pub fn minimum(self, minimum: impl IntoOption<i64>) -> IntegerPropertySchema
Minimum value (inclusive).
Sourcepub fn maximum(self, maximum: impl IntoOption<i64>) -> IntegerPropertySchema
pub fn maximum(self, maximum: impl IntoOption<i64>) -> IntegerPropertySchema
Maximum value (inclusive).
Sourcepub fn default_value(
self,
default: impl IntoOption<i64>,
) -> IntegerPropertySchema
pub fn default_value( self, default: impl IntoOption<i64>, ) -> IntegerPropertySchema
Default value.
Sourcepub fn meta(
self,
meta: impl IntoOption<Map<String, Value>>,
) -> IntegerPropertySchema
pub fn meta( self, meta: impl IntoOption<Map<String, Value>>, ) -> IntegerPropertySchema
The _meta property is reserved by ACP to allow clients and agents to attach additional metadata to their interactions. Implementations MUST NOT make assumptions about values at these keys.
See protocol docs: Extensibility