#[non_exhaustive]pub struct ListSessionsResponse {
pub sessions: Vec<SessionInfo>,
pub next_cursor: Option<String>,
pub meta: Option<Map<String, Value>>,
}unstable_protocol_v2 only.Expand description
Response from listing sessions.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.sessions: Vec<SessionInfo>Array of session information objects
next_cursor: Option<String>Opaque cursor token. If present, pass this in the next request’s cursor parameter to fetch the next page. If absent, there are no more results.
meta: Option<Map<String, Value>>The _meta property is reserved by ACP to allow clients and agents to attach additional metadata to their interactions. Implementations MUST NOT make assumptions about values at these keys.
See protocol docs: Extensibility
Implementations
Sourceimpl ListSessionsResponse
impl ListSessionsResponse
Sourcepub fn new(sessions: Vec<SessionInfo>) -> ListSessionsResponse
pub fn new(sessions: Vec<SessionInfo>) -> ListSessionsResponse
Builds ListSessionsResponse with the required response fields set; optional fields start unset or empty.
Sourcepub fn next_cursor(
self,
next_cursor: impl IntoOption<String>,
) -> ListSessionsResponse
pub fn next_cursor( self, next_cursor: impl IntoOption<String>, ) -> ListSessionsResponse
Sets or clears the optional nextCursor field.
Sourcepub fn meta(
self,
meta: impl IntoOption<Map<String, Value>>,
) -> ListSessionsResponse
pub fn meta( self, meta: impl IntoOption<Map<String, Value>>, ) -> ListSessionsResponse
The _meta property is reserved by ACP to allow clients and agents to attach additional metadata to their interactions. Implementations MUST NOT make assumptions about values at these keys.
See protocol docs: Extensibility