#[non_exhaustive]pub struct LoadSessionResponse {
pub config_options: Option<Vec<SessionConfigOption>>,
pub meta: Option<Map<String, Value>>,
}Available on crate feature
unstable_protocol_v2 only.Expand description
Response from loading an existing session.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.config_options: Option<Vec<SessionConfigOption>>Initial session configuration options if supported by the Agent.
meta: Option<Map<String, Value>>The _meta property is reserved by ACP to allow clients and agents to attach additional metadata to their interactions. Implementations MUST NOT make assumptions about values at these keys.
See protocol docs: Extensibility
Implementations
Sourceimpl LoadSessionResponse
impl LoadSessionResponse
pub fn new() -> LoadSessionResponse
Sourcepub fn config_options(
self,
config_options: impl IntoOption<Vec<SessionConfigOption>>,
) -> LoadSessionResponse
pub fn config_options( self, config_options: impl IntoOption<Vec<SessionConfigOption>>, ) -> LoadSessionResponse
Initial session configuration options if supported by the Agent.
Sourcepub fn meta(
self,
meta: impl IntoOption<Map<String, Value>>,
) -> LoadSessionResponse
pub fn meta( self, meta: impl IntoOption<Map<String, Value>>, ) -> LoadSessionResponse
The _meta property is reserved by ACP to allow clients and agents to attach additional metadata to their interactions. Implementations MUST NOT make assumptions about values at these keys.
See protocol docs: Extensibility