#[non_exhaustive]pub struct LoginAuthRequest {
pub method_id: AuthMethodId,
pub meta: Option<Map<String, Value>>,
}Available on crate feature
unstable_protocol_v2 only.Expand description
Request parameters for the auth/login method.
Specifies which authentication method to use.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.method_id: AuthMethodIdThe ID of the authentication method to use. Must be one of the methods advertised in the initialize response.
meta: Option<Map<String, Value>>The _meta property is reserved by ACP to allow clients and agents to attach additional metadata to their interactions. Implementations MUST NOT make assumptions about values at these keys.
See protocol docs: Extensibility
Implementations
Sourceimpl LoginAuthRequest
impl LoginAuthRequest
Sourcepub fn new(method_id: impl Into<AuthMethodId>) -> LoginAuthRequest
pub fn new(method_id: impl Into<AuthMethodId>) -> LoginAuthRequest
Builds LoginAuthRequest with the required request fields set; optional fields start unset or empty.
Sourcepub fn meta(self, meta: impl IntoOption<Map<String, Value>>) -> LoginAuthRequest
pub fn meta(self, meta: impl IntoOption<Map<String, Value>>) -> LoginAuthRequest
The _meta property is reserved by ACP to allow clients and agents to attach additional metadata to their interactions. Implementations MUST NOT make assumptions about values at these keys.
See protocol docs: Extensibility