#[non_exhaustive]pub struct LogoutAuthRequest {
pub meta: Option<Map<String, Value>>,
}Available on crate feature
unstable_protocol_v2 only.Expand description
Request parameters for the auth/logout method.
Terminates the current authenticated session.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.meta: Option<Map<String, Value>>The _meta property is reserved by ACP to allow clients and agents to attach additional metadata to their interactions. Implementations MUST NOT make assumptions about values at these keys.
See protocol docs: Extensibility
Implementations
Sourceimpl LogoutAuthRequest
impl LogoutAuthRequest
Sourcepub fn new() -> LogoutAuthRequest
pub fn new() -> LogoutAuthRequest
Builds LogoutAuthRequest with the required request fields set; optional fields start unset or empty.
Sourcepub fn meta(
self,
meta: impl IntoOption<Map<String, Value>>,
) -> LogoutAuthRequest
pub fn meta( self, meta: impl IntoOption<Map<String, Value>>, ) -> LogoutAuthRequest
The _meta property is reserved by ACP to allow clients and agents to attach additional metadata to their interactions. Implementations MUST NOT make assumptions about values at these keys.
See protocol docs: Extensibility