#[non_exhaustive]pub struct McpCapabilities {
pub stdio: Option<McpStdioCapabilities>,
pub http: Option<McpHttpCapabilities>,
pub acp: Option<McpAcpCapabilities>,
pub meta: Option<Map<String, Value>>,
}unstable_protocol_v2 only.Expand description
MCP capabilities supported by the agent
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.stdio: Option<McpStdioCapabilities>Agent supports McpServer::Stdio.
Optional. Omitted or null both mean the agent does not advertise support.
Supplying {} means the agent supports stdio MCP server transports.
http: Option<McpHttpCapabilities>Agent supports McpServer::Http.
Optional. Omitted or null both mean the agent does not advertise support.
Supplying {} means the agent supports HTTP MCP server transports.
acp: Option<McpAcpCapabilities>unstable_mcp_over_acp only.UNSTABLE
This capability is not part of the spec yet, and may be removed or changed at any point.
Agent supports McpServer::Acp.
Optional. Omitted or null both mean the agent does not advertise support.
Supplying {} means the agent supports ACP MCP server transports.
meta: Option<Map<String, Value>>The _meta property is reserved by ACP to allow clients and agents to attach additional metadata to their interactions. Implementations MUST NOT make assumptions about values at these keys.
See protocol docs: Extensibility
Implementations
Sourceimpl McpCapabilities
impl McpCapabilities
pub fn new() -> McpCapabilities
Sourcepub fn stdio(
self,
stdio: impl IntoOption<McpStdioCapabilities>,
) -> McpCapabilities
pub fn stdio( self, stdio: impl IntoOption<McpStdioCapabilities>, ) -> McpCapabilities
Agent supports McpServer::Stdio.
Omitted or null both mean the agent does not advertise support.
Supplying {} means the agent supports stdio MCP server transports.
Sourcepub fn http(self, http: impl IntoOption<McpHttpCapabilities>) -> McpCapabilities
pub fn http(self, http: impl IntoOption<McpHttpCapabilities>) -> McpCapabilities
Agent supports McpServer::Http.
Omitted or null both mean the agent does not advertise support.
Supplying {} means the agent supports HTTP MCP server transports.
Sourcepub fn acp(self, acp: impl IntoOption<McpAcpCapabilities>) -> McpCapabilities
Available on crate feature unstable_mcp_over_acp only.
pub fn acp(self, acp: impl IntoOption<McpAcpCapabilities>) -> McpCapabilities
unstable_mcp_over_acp only.UNSTABLE
This capability is not part of the spec yet, and may be removed or changed at any point.
Agent supports McpServer::Acp.
Omitted or null both mean the agent does not advertise support.
Supplying {} means the agent supports ACP MCP server transports.
Sourcepub fn meta(self, meta: impl IntoOption<Map<String, Value>>) -> McpCapabilities
pub fn meta(self, meta: impl IntoOption<Map<String, Value>>) -> McpCapabilities
The _meta property is reserved by ACP to allow clients and agents to attach additional metadata to their interactions. Implementations MUST NOT make assumptions about values at these keys.
See protocol docs: Extensibility