#[non_exhaustive]pub struct McpServerAcp {
pub name: String,
pub id: McpServerAcpId,
pub meta: Option<Map<String, Value>>,
}unstable_protocol_v2 only.Expand description
UNSTABLE
This capability is not part of the spec yet, and may be removed or changed at any point.
ACP transport configuration for MCP.
The MCP server is provided by an ACP component and communicates over the ACP channel
using mcp/connect, mcp/message, and mcp/disconnect.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.name: StringHuman-readable name identifying this MCP server.
id: McpServerAcpIdUnique identifier for this MCP server, generated by the component providing it.
Providers MUST NOT reuse an ID for multiple ACP-transport MCP servers that are visible on the same ACP connection.
meta: Option<Map<String, Value>>The _meta property is reserved by ACP to allow clients and agents to attach additional metadata to their interactions. Implementations MUST NOT make assumptions about values at these keys.
See protocol docs: Extensibility
Implementations
Sourceimpl McpServerAcp
impl McpServerAcp
pub fn new( name: impl Into<String>, id: impl Into<McpServerAcpId>, ) -> McpServerAcp
unstable_mcp_over_acp only.Sourcepub fn meta(self, meta: impl IntoOption<Map<String, Value>>) -> McpServerAcp
Available on crate feature unstable_mcp_over_acp only.
pub fn meta(self, meta: impl IntoOption<Map<String, Value>>) -> McpServerAcp
unstable_mcp_over_acp only.The _meta property is reserved by ACP to allow clients and agents to attach additional metadata to their interactions. Implementations MUST NOT make assumptions about values at these keys.
See protocol docs: Extensibility