#[non_exhaustive]pub struct McpServerAcpId(pub Arc<str>);Available on crate features
unstable_mcp_over_acp and unstable_protocol_v2 only.Expand description
UNSTABLE
This capability is not part of the spec yet, and may be removed or changed at any point.
Unique identifier for an MCP server using the ACP transport.
The value is opaque and generated by the ACP component providing the MCP server. It is
used by mcp/connect to route connection requests back to the component that declared the
server.
Tuple Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.0: Arc<str>Implementations