#[non_exhaustive]pub struct McpServerHttp {
pub name: String,
pub url: String,
pub headers: Vec<HttpHeader>,
pub meta: Option<Map<String, Value>>,
}unstable_protocol_v2 only.Expand description
HTTP transport configuration for MCP.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.name: StringHuman-readable name identifying this MCP server.
url: StringURL to the MCP server.
headers: Vec<HttpHeader>HTTP headers to set when making requests to the MCP server.
meta: Option<Map<String, Value>>The _meta property is reserved by ACP to allow clients and agents to attach additional metadata to their interactions. Implementations MUST NOT make assumptions about values at these keys.
See protocol docs: Extensibility
Implementations
Sourceimpl McpServerHttp
impl McpServerHttp
Sourcepub fn new(name: impl Into<String>, url: impl Into<String>) -> McpServerHttp
pub fn new(name: impl Into<String>, url: impl Into<String>) -> McpServerHttp
Builds McpServerHttp with the required fields set; optional fields start unset or empty.
Sourcepub fn headers(self, headers: Vec<HttpHeader>) -> McpServerHttp
pub fn headers(self, headers: Vec<HttpHeader>) -> McpServerHttp
HTTP headers to set when making requests to the MCP server.
Sourcepub fn meta(self, meta: impl IntoOption<Map<String, Value>>) -> McpServerHttp
pub fn meta(self, meta: impl IntoOption<Map<String, Value>>) -> McpServerHttp
The _meta property is reserved by ACP to allow clients and agents to attach additional metadata to their interactions. Implementations MUST NOT make assumptions about values at these keys.
See protocol docs: Extensibility