#[non_exhaustive]pub struct MessageMcpResponse(pub Arc<RawValue>);Available on crate feature
unstable_protocol_v2 only.Expand description
UNSTABLE
This capability is not part of the spec yet, and may be removed or changed at any point.
Response to mcp/message.
This is the inner MCP response result payload. Any JSON value is valid.
Tuple Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.0: Arc<RawValue>Implementations
Sourceimpl MessageMcpResponse
impl MessageMcpResponse
pub fn new(result: Arc<RawValue>) -> MessageMcpResponse