OtherAuthMethod

Struct OtherAuthMethod 

#[non_exhaustive]
pub struct OtherAuthMethod { pub type_: String, pub id: AuthMethodId, pub name: String, pub description: Option<String>, pub meta: Option<Map<String, Value>>, pub fields: BTreeMap<String, Value>, }
Available on crate feature unstable_protocol_v2 only.
Custom or future authentication method payload.

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
type_: String

Custom or future authentication method type.

Values beginning with _ are reserved for implementation-specific extensions. Unknown values that do not begin with _ are reserved for future ACP variants.

id: AuthMethodId

Unique identifier for this authentication method.

name: String

Human-readable name of the authentication method.

description: Option<String>

Optional description providing more details about this authentication method.

meta: Option<Map<String, Value>>

The _meta property is reserved by ACP to allow clients and agents to attach additional metadata to their interactions. Implementations MUST NOT make assumptions about values at these keys.

See protocol docs: Extensibility

fields: BTreeMap<String, Value>

Additional fields from the unknown authentication method payload.

Implementations

Source

impl OtherAuthMethod

pub fn new( type_: impl Into<String>, id: impl Into<AuthMethodId>, name: impl Into<String>, fields: BTreeMap<String, Value>, ) -> OtherAuthMethod

pub fn description( self, description: impl IntoOption<String>, ) -> OtherAuthMethod

Optional description providing more details about this authentication method.

pub fn meta(self, meta: impl IntoOption<Map<String, Value>>) -> OtherAuthMethod

The _meta property is reserved by ACP to allow clients and agents to attach additional metadata to their interactions. Implementations MUST NOT make assumptions about values at these keys.

See protocol docs: Extensibility