#[non_exhaustive]pub struct OtherElicitationAction {
pub action: String,
pub fields: BTreeMap<String, Value>,
}Available on crate feature
unstable_protocol_v2 only.Expand description
Custom or future elicitation action payload.
This preserves the unknown action discriminator and the rest of the
response object for agents that store, replay, proxy, or forward elicitation
responses.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.action: StringCustom or future elicitation action.
Values beginning with _ are reserved for implementation-specific
extensions. Unknown values that do not begin with _ are reserved for
future ACP variants.
fields: BTreeMap<String, Value>Additional fields from the unknown elicitation action payload.
Implementations
Sourceimpl OtherElicitationAction
impl OtherElicitationAction
Sourcepub fn new(
action: impl Into<String>,
fields: BTreeMap<String, Value>,
) -> OtherElicitationAction
pub fn new( action: impl Into<String>, fields: BTreeMap<String, Value>, ) -> OtherElicitationAction
Builds OtherElicitationAction from an unknown discriminator and preserves the remaining extension fields.