#[non_exhaustive]pub struct OtherReplayFrom {
pub type_: String,
pub meta: Option<Map<String, Value>>,
pub fields: BTreeMap<String, Value>,
}unstable_protocol_v2 only.Expand description
Custom or future replay cursor payload.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.type_: StringCustom or future replay cursor type.
Values beginning with _ are reserved for implementation-specific
extensions. Unknown values that do not begin with _ are reserved for
future ACP variants.
meta: Option<Map<String, Value>>The _meta property is reserved by ACP to allow clients and agents to attach additional metadata to their interactions. Implementations MUST NOT make assumptions about values at these keys.
See protocol docs: Extensibility
fields: BTreeMap<String, Value>Additional fields from the unknown replay cursor payload.
Implementations
Sourceimpl OtherReplayFrom
impl OtherReplayFrom
Sourcepub fn new(
type_: impl Into<String>,
fields: BTreeMap<String, Value>,
) -> OtherReplayFrom
pub fn new( type_: impl Into<String>, fields: BTreeMap<String, Value>, ) -> OtherReplayFrom
Builds OtherReplayFrom from an unknown discriminator and preserves the remaining extension fields.
Sourcepub fn meta(self, meta: impl IntoOption<Map<String, Value>>) -> OtherReplayFrom
pub fn meta(self, meta: impl IntoOption<Map<String, Value>>) -> OtherReplayFrom
The _meta property is reserved by ACP to allow clients and agents to attach additional metadata to their interactions. Implementations MUST NOT make assumptions about values at these keys.
See protocol docs: Extensibility