#[non_exhaustive]pub struct OtherSessionConfigOptionValue {
pub type_: String,
pub value: Value,
pub fields: BTreeMap<String, Value>,
}Available on crate feature
unstable_protocol_v2 only.Expand description
Custom or future session configuration option value payload.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.type_: StringCustom or future session configuration option value type.
Values beginning with _ are reserved for implementation-specific
extensions. Unknown values that do not begin with _ are reserved for
future ACP variants.
value: ValueRaw value payload for the custom or future value type.
fields: BTreeMap<String, Value>Additional fields from the unknown session configuration option value payload.
Implementations
Sourceimpl OtherSessionConfigOptionValue
impl OtherSessionConfigOptionValue
Sourcepub fn new(
type_: impl Into<String>,
value: Value,
fields: BTreeMap<String, Value>,
) -> OtherSessionConfigOptionValue
pub fn new( type_: impl Into<String>, value: Value, fields: BTreeMap<String, Value>, ) -> OtherSessionConfigOptionValue
Builds OtherSessionConfigOptionValue from an unknown discriminator and preserves the remaining extension fields.