#[non_exhaustive]pub struct PlanItems {
pub id: PlanId,
pub entries: Vec<PlanEntry>,
pub meta: Option<Map<String, Value>>,
}unstable_protocol_v2 only.Expand description
A plan represented as structured entries.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.id: PlanIdThe plan ID to update.
entries: Vec<PlanEntry>The list of tasks to be accomplished.
When updating an item-based plan, the agent must send a complete list of all entries with their current status. The client replaces that plan with each update.
meta: Option<Map<String, Value>>The _meta property is reserved by ACP to allow clients and agents to attach additional metadata to their interactions. Implementations MUST NOT make assumptions about values at these keys.
See protocol docs: Extensibility
Implementations
Sourceimpl PlanItems
impl PlanItems
Sourcepub fn new(id: impl Into<PlanId>, entries: Vec<PlanEntry>) -> PlanItems
pub fn new(id: impl Into<PlanId>, entries: Vec<PlanEntry>) -> PlanItems
Builds PlanItems with the required fields set; optional fields start unset or empty.
Sourcepub fn meta(self, meta: impl IntoOption<Map<String, Value>>) -> PlanItems
pub fn meta(self, meta: impl IntoOption<Map<String, Value>>) -> PlanItems
The _meta property is reserved by ACP to allow clients and agents to attach additional metadata to their interactions. Implementations MUST NOT make assumptions about values at these keys.
See protocol docs: Extensibility