#[non_exhaustive]pub struct PlanUpdate {
pub plan: PlanUpdateContent,
pub meta: Option<Map<String, Value>>,
}Available on crate feature
unstable_protocol_v2 only.Expand description
A content update for a plan identified by ID.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.plan: PlanUpdateContentThe updated plan content.
meta: Option<Map<String, Value>>The _meta property is reserved by ACP to allow clients and agents to attach additional metadata to their interactions. Implementations MUST NOT make assumptions about values at these keys.
See protocol docs: Extensibility
Implementations
Sourceimpl PlanUpdate
impl PlanUpdate
pub fn new(plan: PlanUpdateContent) -> PlanUpdate
Sourcepub fn meta(self, meta: impl IntoOption<Map<String, Value>>) -> PlanUpdate
pub fn meta(self, meta: impl IntoOption<Map<String, Value>>) -> PlanUpdate
The _meta property is reserved by ACP to allow clients and agents to attach additional metadata to their interactions. Implementations MUST NOT make assumptions about values at these keys.
See protocol docs: Extensibility