#[non_exhaustive]pub struct PromptEmbeddedContextCapabilities {
pub meta: Option<Map<String, Value>>,
}Available on crate feature
unstable_protocol_v2 only.Expand description
Capabilities for embedded context in prompt requests.
Supplying {} means the agent supports embedded context in prompts.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.meta: Option<Map<String, Value>>The _meta property is reserved by ACP to allow clients and agents to attach additional metadata to their interactions. Implementations MUST NOT make assumptions about values at these keys.
See protocol docs: Extensibility
Implementations
Sourceimpl PromptEmbeddedContextCapabilities
impl PromptEmbeddedContextCapabilities
pub fn new() -> PromptEmbeddedContextCapabilities
Sourcepub fn meta(
self,
meta: impl IntoOption<Map<String, Value>>,
) -> PromptEmbeddedContextCapabilities
pub fn meta( self, meta: impl IntoOption<Map<String, Value>>, ) -> PromptEmbeddedContextCapabilities
The _meta property is reserved by ACP to allow clients and agents to attach additional metadata to their interactions. Implementations MUST NOT make assumptions about values at these keys.
See protocol docs: Extensibility