#[non_exhaustive]pub struct SessionConfigBoolean {
pub current_value: bool,
}Available on crate features
unstable_boolean_config and unstable_protocol_v2 only.Expand description
UNSTABLE
This capability is not part of the spec yet, and may be removed or changed at any point.
A boolean on/off toggle session configuration option payload.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.current_value: boolThe current value of the boolean option.
Implementations
Sourceimpl SessionConfigBoolean
impl SessionConfigBoolean
pub fn new(current_value: bool) -> SessionConfigBoolean