#[non_exhaustive]pub struct SessionConfigOption {
pub id: SessionConfigId,
pub name: String,
pub description: Option<String>,
pub category: Option<SessionConfigOptionCategory>,
pub kind: SessionConfigKind,
pub meta: Option<Map<String, Value>>,
}unstable_protocol_v2 only.Expand description
A session configuration option selector and its current state.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.id: SessionConfigIdUnique identifier for the configuration option.
name: StringHuman-readable label for the option.
description: Option<String>Optional description for the Client to display to the user.
category: Option<SessionConfigOptionCategory>Optional semantic category for this option (UX only).
kind: SessionConfigKindType-specific fields for this configuration option.
meta: Option<Map<String, Value>>The _meta property is reserved by ACP to allow clients and agents to attach additional metadata to their interactions. Implementations MUST NOT make assumptions about values at these keys.
See protocol docs: Extensibility
Implementations
Sourceimpl SessionConfigOption
impl SessionConfigOption
pub fn new( id: impl Into<SessionConfigId>, name: impl Into<String>, kind: SessionConfigKind, ) -> SessionConfigOption
pub fn select( id: impl Into<SessionConfigId>, name: impl Into<String>, current_value: impl Into<SessionConfigValueId>, options: impl Into<SessionConfigSelectOptions>, ) -> SessionConfigOption
Sourcepub fn boolean(
id: impl Into<SessionConfigId>,
name: impl Into<String>,
current_value: bool,
) -> SessionConfigOption
Available on crate feature unstable_boolean_config only.
pub fn boolean( id: impl Into<SessionConfigId>, name: impl Into<String>, current_value: bool, ) -> SessionConfigOption
unstable_boolean_config only.UNSTABLE
This capability is not part of the spec yet, and may be removed or changed at any point.
pub fn description( self, description: impl IntoOption<String>, ) -> SessionConfigOption
pub fn category( self, category: impl IntoOption<SessionConfigOptionCategory>, ) -> SessionConfigOption
Sourcepub fn meta(
self,
meta: impl IntoOption<Map<String, Value>>,
) -> SessionConfigOption
pub fn meta( self, meta: impl IntoOption<Map<String, Value>>, ) -> SessionConfigOption
The _meta property is reserved by ACP to allow clients and agents to attach additional metadata to their interactions. Implementations MUST NOT make assumptions about values at these keys.
See protocol docs: Extensibility