#[non_exhaustive]pub struct SessionConfigSelectOption {
pub value: SessionConfigValueId,
pub name: String,
pub description: Option<String>,
pub meta: Option<Map<String, Value>>,
}unstable_protocol_v2 only.Expand description
A possible value for a session configuration option.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.value: SessionConfigValueIdUnique identifier for this option value.
name: StringHuman-readable label for this option value.
description: Option<String>Optional description for this option value.
meta: Option<Map<String, Value>>The _meta property is reserved by ACP to allow clients and agents to attach additional metadata to their interactions. Implementations MUST NOT make assumptions about values at these keys.
See protocol docs: Extensibility
Implementations
Sourceimpl SessionConfigSelectOption
impl SessionConfigSelectOption
Sourcepub fn new(
value: impl Into<SessionConfigValueId>,
name: impl Into<String>,
) -> SessionConfigSelectOption
pub fn new( value: impl Into<SessionConfigValueId>, name: impl Into<String>, ) -> SessionConfigSelectOption
Builds SessionConfigSelectOption with the required fields set; optional fields start unset or empty.
Sourcepub fn description(
self,
description: impl IntoOption<String>,
) -> SessionConfigSelectOption
pub fn description( self, description: impl IntoOption<String>, ) -> SessionConfigSelectOption
Sets or clears the optional description field.
Sourcepub fn meta(
self,
meta: impl IntoOption<Map<String, Value>>,
) -> SessionConfigSelectOption
pub fn meta( self, meta: impl IntoOption<Map<String, Value>>, ) -> SessionConfigSelectOption
The _meta property is reserved by ACP to allow clients and agents to attach additional metadata to their interactions. Implementations MUST NOT make assumptions about values at these keys.
See protocol docs: Extensibility