SessionForkCapabilities

Struct SessionForkCapabilities 

#[non_exhaustive]
pub struct SessionForkCapabilities { pub meta: Option<Map<String, Value>>, }
Available on crate feature unstable_protocol_v2 only.
UNSTABLE

This capability is not part of the spec yet, and may be removed or changed at any point.

Capabilities for the session/fork method.

By supplying {} it means that the agent supports forking of sessions.

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
meta: Option<Map<String, Value>>

The _meta property is reserved by ACP to allow clients and agents to attach additional metadata to their interactions. Implementations MUST NOT make assumptions about values at these keys.

See protocol docs: Extensibility

Implementations

Source

impl SessionForkCapabilities

pub fn new() -> SessionForkCapabilities

Available on crate feature unstable_session_fork only.
pub fn meta( self, meta: impl IntoOption<Map<String, Value>>, ) -> SessionForkCapabilities

Available on crate feature unstable_session_fork only.

The _meta property is reserved by ACP to allow clients and agents to attach additional metadata to their interactions. Implementations MUST NOT make assumptions about values at these keys.

See protocol docs: Extensibility