#[non_exhaustive]pub struct SessionMessageChunk {
pub message_id: MessageId,
pub sender_session_id: Option<SessionId>,
pub recipient_session_id: Option<SessionId>,
pub content: ContentBlock,
pub meta: Option<Map<String, Value>>,
}unstable_protocol_v2 only.Expand description
UNSTABLE
This capability is not part of the spec yet, and may be removed or changed at any point.
A streamed content block of an inter-session message.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.message_id: MessageIdIdentifier of this message within the enclosing session’s transcript.
sender_session_id: Option<SessionId>Optional sending session identity; omission or null retains a known value.
recipient_session_id: Option<SessionId>Optional receiving session identity; omission or null retains a known value.
content: ContentBlockA single content block appended to the message.
meta: Option<Map<String, Value>>Optional and nullable chunk-scoped metadata; omitted or null means none.
Implementations MUST NOT make assumptions about values in _meta.
Implementations
Sourceimpl SessionMessageChunk
impl SessionMessageChunk
Sourcepub fn new(
message_id: impl Into<MessageId>,
content: ContentBlock,
) -> SessionMessageChunk
Available on crate feature unstable_subagents only.
pub fn new( message_id: impl Into<MessageId>, content: ContentBlock, ) -> SessionMessageChunk
unstable_subagents only.Builds a single streamed content block without chunk metadata.
Sourcepub fn sender_session_id(
self,
sender_session_id: impl IntoOption<SessionId>,
) -> SessionMessageChunk
Available on crate feature unstable_subagents only.
pub fn sender_session_id( self, sender_session_id: impl IntoOption<SessionId>, ) -> SessionMessageChunk
unstable_subagents only.Supplies the sending session identity, when known.
Sourcepub fn recipient_session_id(
self,
recipient_session_id: impl IntoOption<SessionId>,
) -> SessionMessageChunk
Available on crate feature unstable_subagents only.
pub fn recipient_session_id( self, recipient_session_id: impl IntoOption<SessionId>, ) -> SessionMessageChunk
unstable_subagents only.Supplies the receiving session identity, when known.
Sourcepub fn meta(
self,
meta: impl IntoOption<Map<String, Value>>,
) -> SessionMessageChunk
Available on crate feature unstable_subagents only.
pub fn meta( self, meta: impl IntoOption<Map<String, Value>>, ) -> SessionMessageChunk
unstable_subagents only.Sets optional chunk-scoped metadata.