#[non_exhaustive]pub struct TextResourceContents {
pub mime_type: Option<String>,
pub text: String,
pub uri: String,
pub meta: Option<Map<String, Value>>,
}unstable_protocol_v2 only.Expand description
Text-based resource contents.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.mime_type: Option<String>MIME type describing the encoded media payload.
text: StringText payload carried by this content block.
uri: StringURI associated with this resource or media payload.
meta: Option<Map<String, Value>>The _meta property is reserved by ACP to allow clients and agents to attach additional metadata to their interactions. Implementations MUST NOT make assumptions about values at these keys.
See protocol docs: Extensibility
Implementations
Sourceimpl TextResourceContents
impl TextResourceContents
Sourcepub fn new(
text: impl Into<String>,
uri: impl Into<String>,
) -> TextResourceContents
pub fn new( text: impl Into<String>, uri: impl Into<String>, ) -> TextResourceContents
Builds TextResourceContents with its required content payload; optional annotations and metadata start unset.
Sourcepub fn mime_type(
self,
mime_type: impl IntoOption<String>,
) -> TextResourceContents
pub fn mime_type( self, mime_type: impl IntoOption<String>, ) -> TextResourceContents
Sets or clears the optional mimeType field.
Sourcepub fn meta(
self,
meta: impl IntoOption<Map<String, Value>>,
) -> TextResourceContents
pub fn meta( self, meta: impl IntoOption<Map<String, Value>>, ) -> TextResourceContents
The _meta property is reserved by ACP to allow clients and agents to attach additional metadata to their interactions. Implementations MUST NOT make assumptions about values at these keys.
See protocol docs: Extensibility