ToolCallContentChunk

Struct ToolCallContentChunk 

#[non_exhaustive]
pub struct ToolCallContentChunk { pub tool_call_id: ToolCallId, pub content: ToolCallContent, pub meta: Option<Map<String, Value>>, }
Available on crate feature unstable_protocol_v2 only.
A streamed item of tool-call content.

Tool-call content chunks append one ToolCallContent item to the current content for the matching ToolCallId. Agents can use ToolCallUpdate::content when they need to replace the whole content collection instead.

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
tool_call_id: ToolCallId

The ID of the tool call this content belongs to.

content: ToolCallContent

A single item of content produced by the tool call.

meta: Option<Map<String, Value>>

The _meta property is reserved by ACP to allow clients and agents to attach additional metadata to their interactions. Implementations MUST NOT make assumptions about values at these keys. This field is optional; omitted or null means there is no chunk-level metadata.

See protocol docs: Extensibility

Implementations

Source

impl ToolCallContentChunk

pub fn new( tool_call_id: impl Into<ToolCallId>, content: impl Into<ToolCallContent>, ) -> ToolCallContentChunk

Builds ToolCallContentChunk with the required fields set; optional fields start unset or empty.

pub fn meta( self, meta: impl IntoOption<Map<String, Value>>, ) -> ToolCallContentChunk

The _meta property is reserved by ACP to allow clients and agents to attach additional metadata to their interactions. Implementations MUST NOT make assumptions about values at these keys.

See protocol docs: Extensibility