#[non_exhaustive]pub struct ListSessionsRequest {
pub cwd: Option<PathBuf>,
pub cursor: Option<String>,
pub meta: Option<Map<String, Value>>,
}Expand description
Request parameters for listing existing sessions.
Only available if the Agent supports the sessionCapabilities.list capability.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.cwd: Option<PathBuf>Filter sessions by working directory. Must be an absolute path.
cursor: Option<String>Opaque cursor token from a previous response’s nextCursor field for cursor-based pagination
meta: Option<Map<String, Value>>The _meta property is reserved by ACP to allow clients and agents to attach additional metadata to their interactions. Implementations MUST NOT make assumptions about values at these keys.
See protocol docs: Extensibility
Implementations
Sourceimpl ListSessionsRequest
impl ListSessionsRequest
pub fn new() -> ListSessionsRequest
Sourcepub fn cwd(self, cwd: impl IntoOption<PathBuf>) -> ListSessionsRequest
pub fn cwd(self, cwd: impl IntoOption<PathBuf>) -> ListSessionsRequest
Filter sessions by working directory. Must be an absolute path.
Sourcepub fn cursor(self, cursor: impl IntoOption<String>) -> ListSessionsRequest
pub fn cursor(self, cursor: impl IntoOption<String>) -> ListSessionsRequest
Opaque cursor token from a previous response’s nextCursor field for cursor-based pagination
Sourcepub fn meta(
self,
meta: impl IntoOption<Map<String, Value>>,
) -> ListSessionsRequest
pub fn meta( self, meta: impl IntoOption<Map<String, Value>>, ) -> ListSessionsRequest
The _meta property is reserved by ACP to allow clients and agents to attach additional metadata to their interactions. Implementations MUST NOT make assumptions about values at these keys.
See protocol docs: Extensibility