Stdio

Struct Stdio 

pub struct Stdio { /* private fields */ }
A transport that connects to an ACP peer via standard input/output.

This is useful for building agents or proxies that communicate over stdio, which is the standard transport for MCP and ACP subprocess communication.

Implementations

Source

impl Stdio

pub fn new() -> Self

Create a new Stdio transport.

pub fn with_debug<F>(self, callback: F) -> Self
where F: Fn(&str, LineDirection) + Send + Sync + 'static,

Add a debug callback that will be invoked for each line sent/received.