MetaCapability

Trait MetaCapability 

pub trait MetaCapability {
    // Required method
    fn key(&self) -> &'static str;

    // Provided method
    fn value(&self) -> Value { ... }
}
Trait for capabilities stored in the _meta.symposium object.

Capabilities are key-value pairs that signal features or context to components in the proxy chain. Implement this trait to define new capabilities.

Required Methods

fn key(&self) -> &'static str

The key name in the _meta.symposium object (e.g., “proxy”, “mcp_acp_transport”)

Provided Methods

fn value(&self) -> Value

The value to set when adding this capability (defaults to true)

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors