pub struct DynConnectTo<R: Role> { /* private fields */ }Expand description
A dynamically-typed component for heterogeneous collections.
This type wraps any ConnectTo implementation and provides dynamic dispatch,
allowing you to store different component types in the same collection.
The type parameter R is the role that all components in the
collection serve (their counterpart).
Examples
ⓘ
use agent_client_protocol::{DynConnectTo, Client};
let components: Vec<DynConnectTo<Client>> = vec![
DynConnectTo::new(Proxy1),
DynConnectTo::new(Proxy2),
DynConnectTo::new(Agent),
];Implementations