JSON-RPC message types.
This module re-exports types from the jsonrpcmsg crate that are transitively
reachable through the public API (e.g., via Channel).
Users of the agent-client-protocol crate can use these types without adding a direct dependency
on jsonrpcmsg.