tool_fn

Macro tool_fn 

macro_rules! tool_fn {
    () => { ... };
}
This is a hack that must be given as the final argument of the MCP server builder’s tool_fn method when defining stateless concurrent tools.

The agent-client-protocol-rmcp crate provides the builder this macro is typically used with. See tool_fn_mut! for the gory details.