macro_rules! tool_fn_mut {
() => { ... };
}Expand description
This is a hack that must be given as the final argument of
McpServerBuilder::tool_fn when defining tools.
Look away, lest ye be blinded by its vileness!
Fine, if you MUST know, it’s a horrific workaround for not having return-type notation and for this !@$#!%! bug. Trust me, the need for it hurts me more than it hurts you. –nikomatsakis