Role types for ACP connections Role types for ACP connections.
Roles represent the logical identity of an endpoint in an ACP connection. Each role has a counterpart (who it connects to) and may have multiple peers (who it can exchange messages with).
Modules
- acp
- Roles for the ACP protocol.
- mcp
- Roles for the MCP protocol. MCP (Model Context Protocol) role types.
Structs
- Untyped
Role - A dummy role you can use to exchange JSON-RPC messages without any knowledge of the underlying protocol. Don’t sue this.
Enums
- Remote
Style - Describes how messages are transformed when sent to a remote peer.
- RoleId
- Unique identifier for a role instance.