Roles for the ACP protocol.
Structs
- Agent
- The agent role - typically an LLM that responds to prompts.
- Agent
Protocol Router unstable_protocol_v2 - Agent component that routes each connection to a configured protocol implementation.
- Client
- The client role - typically an IDE or CLI that controls an agent.
- Client
Protocol Connector unstable_protocol_v2 - Client connector that opens an agent connection with a configured protocol implementation.
- Conductor
- The conductor role - orchestrates proxy chains.
- Proxy
- The proxy role - an intermediary that can intercept and modify messages.