ACP protocol schema types - all message types, requests, responses, and supporting types ACP protocol schema types and message implementations.
This module contains all the types from the Agent-Client Protocol schema, including requests, responses, notifications, and supporting types. All types are re-exported flatly from this module.
Modules
- v1
- Agent Client Protocol v1 schema types.
- v2
unstable_protocol_v2 - Agent Client Protocol v2 draft schema types.
Structs
- Initialize
Proxy Request - Initialize request for proxy components.
- Protocol
Version - Protocol version identifier.
- Successor
Message - A message being sent to the successor component.
Enums
- Maybe
Undefined - Similar to
Option, but it has three states,undefined,nullandx.
Constants
- METHOD_
INITIALIZE_ PROXY - JSON-RPC method name for proxy initialization.
- METHOD_
SUCCESSOR_ MESSAGE - JSON-RPC method name for successor forwarding.
Traits
- Into
Maybe Undefined - Utility trait for builder methods for optional values.
This allows the caller to either pass in the value itself without wrapping it in
Some, or to just pass in an Option if that is what they have, or set it back to undefined. - Into
Option - Utility trait for builder methods for optional values.
This allows the caller to either pass in the value itself without wrapping it in
Some, or to just pass in an Option if that is what they have.