ACP protocol schema types - all message types, requests, responses, and supporting types ACP protocol schema types and message implementations.
This module contains all the types from the Agent-Client Protocol schema, including requests, responses, notifications, and supporting types. All types are re-exported flatly from this module.
Modules
- v1
- Agent Client Protocol v1 schema types.
- v2
unstable_protocol_v2 - Agent Client Protocol v2 draft schema types.
Structs
- Initialize
Proxy Request - Initialize request for proxy components.
- McpConnect
Request - Creates a new MCP connection. This is equivalent to “running the command”.
- McpConnect
Response - Response to an MCP connect request
- McpDisconnect
Notification - Disconnects the MCP connection.
- McpOver
AcpMessage - An MCP request sent via ACP. This could be an MCP-server-to-MCP-client request (in which case it goes from the ACP client to the ACP agent, note the reversal of roles) or an MCP-client-to-MCP-server request (in which case it goes from the ACP agent to the ACP client).
- Protocol
Version - Protocol version identifier.
- Successor
Message - A message being sent to the successor component.
Enums
- Maybe
Undefined - Similar to
Option, but it has three states,undefined,nullandx.
Constants
- METHOD_
INITIALIZE_ PROXY - JSON-RPC method name for proxy initialization.
- METHOD_
MCP_ CONNECT_ REQUEST - JSON-RPC method name for MCP connect requests
- METHOD_
MCP_ DISCONNECT_ NOTIFICATION - JSON-RPC method name for MCP disconnect notifications
- METHOD_
MCP_ MESSAGE - JSON-RPC method name for MCP requests over ACP
- METHOD_
SUCCESSOR_ MESSAGE - JSON-RPC method name for successor forwarding.
Traits
- Into
Maybe Undefined - Utility trait for builder methods for optional values.
This allows the caller to either pass in the value itself without wrapping it in
Some, or to just pass in an Option if that is what they have, or set it back to undefined. - Into
Option - Utility trait for builder methods for optional values.
This allows the caller to either pass in the value itself without wrapping it in
Some, or to just pass in an Option if that is what they have.