#[non_exhaustive]pub struct AuthEnvVar {
pub name: String,
pub label: Option<String>,
pub secret: bool,
pub optional: bool,
pub meta: Option<Map<String, Value>>,
}Expand description
UNSTABLE
This capability is not part of the spec yet, and may be removed or changed at any point.
Describes a single environment variable for an AuthMethodEnvVar authentication method.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.name: StringThe environment variable name (e.g. "OPENAI_API_KEY").
label: Option<String>Human-readable label for this variable, displayed in client UI.
secret: boolWhether this value is a secret (e.g. API key, token). Clients should use a password-style input for secret vars.
Defaults to true.
optional: boolWhether this variable is optional.
Defaults to false.
meta: Option<Map<String, Value>>The _meta property is reserved by ACP to allow clients and agents to attach additional metadata to their interactions. Implementations MUST NOT make assumptions about values at these keys.
See protocol docs: Extensibility
Implementations
Sourceimpl AuthEnvVar
impl AuthEnvVar
Sourcepub fn new(name: impl Into<String>) -> AuthEnvVar
Available on crate feature unstable_auth_methods only.
pub fn new(name: impl Into<String>) -> AuthEnvVar
unstable_auth_methods only.Creates a new auth env var.
Sourcepub fn label(self, label: impl IntoOption<String>) -> AuthEnvVar
Available on crate feature unstable_auth_methods only.
pub fn label(self, label: impl IntoOption<String>) -> AuthEnvVar
unstable_auth_methods only.Human-readable label for this variable, displayed in client UI.
Sourcepub fn secret(self, secret: bool) -> AuthEnvVar
Available on crate feature unstable_auth_methods only.
pub fn secret(self, secret: bool) -> AuthEnvVar
unstable_auth_methods only.Whether this value is a secret (e.g. API key, token). Clients should use a password-style input for secret vars.
Sourcepub fn optional(self, optional: bool) -> AuthEnvVar
Available on crate feature unstable_auth_methods only.
pub fn optional(self, optional: bool) -> AuthEnvVar
unstable_auth_methods only.Whether this variable is optional.
Sourcepub fn meta(self, meta: impl IntoOption<Map<String, Value>>) -> AuthEnvVar
Available on crate feature unstable_auth_methods only.
pub fn meta(self, meta: impl IntoOption<Map<String, Value>>) -> AuthEnvVar
unstable_auth_methods only.The _meta property is reserved by ACP to allow clients and agents to attach additional metadata to their interactions. Implementations MUST NOT make assumptions about values at these keys.
See protocol docs: Extensibility