#[non_exhaustive]pub struct CreateElicitationRequest {
pub mode: ElicitationMode,
pub message: String,
pub meta: Option<Map<String, Value>>,
}Expand description
UNSTABLE
This capability is not part of the spec yet, and may be removed or changed at any point.
Request from the agent to elicit structured user input.
The agent sends this to the client to request information from the user, either via a form or by directing them to a URL. Elicitations are tied to a session (optionally a tool call) or a request.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.mode: ElicitationModeThe elicitation mode and its mode-specific fields.
message: StringA human-readable message describing what input is needed.
meta: Option<Map<String, Value>>The _meta property is reserved by ACP to allow clients and agents to attach additional metadata to their interactions. Implementations MUST NOT make assumptions about values at these keys.
See protocol docs: Extensibility
Implementations
Sourceimpl CreateElicitationRequest
impl CreateElicitationRequest
pub fn new( mode: impl Into<ElicitationMode>, message: impl Into<String>, ) -> CreateElicitationRequest
Sourcepub fn scope(&self) -> &ElicitationScope
pub fn scope(&self) -> &ElicitationScope
Returns the scope this elicitation is tied to.
Sourcepub fn meta(
self,
meta: impl IntoOption<Map<String, Value>>,
) -> CreateElicitationRequest
pub fn meta( self, meta: impl IntoOption<Map<String, Value>>, ) -> CreateElicitationRequest
The _meta property is reserved by ACP to allow clients and agents to attach additional metadata to their interactions. Implementations MUST NOT make assumptions about values at these keys.
See protocol docs: Extensibility