pub struct ProtocolVersion(/* private fields */);Expand description
Protocol version identifier.
This version is only bumped for breaking changes. Non-breaking changes should be introduced via capabilities.
Implementations
Sourceimpl ProtocolVersion
impl ProtocolVersion
Sourcepub const V0: ProtocolVersion
pub const V0: ProtocolVersion
Version 0 of the protocol.
This was a pre-release version that shouldn’t be used in production. It is used as a fallback for any request whose version cannot be parsed as a valid version, and should likely be treated as unsupported.
Sourcepub const V1: ProtocolVersion
pub const V1: ProtocolVersion
Version 1 of the protocol.
Sourcepub const V2: ProtocolVersion
Available on crate feature unstable_protocol_v2 only.
pub const V2: ProtocolVersion
unstable_protocol_v2 only.Version 2 of the protocol.
This is an unstable draft used for protocol iteration. It is only
available when the unstable_protocol_v2 feature is enabled and is
not advertised by ProtocolVersion::LATEST yet — callers must
opt into V2 explicitly.
Sourcepub const LATEST: ProtocolVersion = Self::V1
pub const LATEST: ProtocolVersion = Self::V1
The latest stable supported version of the protocol.
Currently this is version 1. Enabling the unstable_protocol_v2
feature exposes ProtocolVersion::V2 but does not change the
value of LATEST — v2 will only become the latest once it stabilizes.