#[non_exhaustive]pub enum AgentResponse {
Show 14 variants
InitializeResponse(Box<InitializeResponse>),
AuthenticateResponse(AuthenticateResponse),
LogoutResponse(LogoutResponse),
NewSessionResponse(NewSessionResponse),
LoadSessionResponse(LoadSessionResponse),
ListSessionsResponse(ListSessionsResponse),
DeleteSessionResponse(DeleteSessionResponse),
ForkSessionResponse(ForkSessionResponse),
ResumeSessionResponse(ResumeSessionResponse),
CloseSessionResponse(CloseSessionResponse),
SetSessionConfigOptionResponse(SetSessionConfigOptionResponse),
PromptResponse(PromptResponse),
ExtMethodResponse(ExtResponse),
MessageMcpResponse(MessageMcpResponse),
}unstable_protocol_v2 only.Expand description
All possible responses that an agent can send to a client.
This enum is used internally for routing RPC responses. You typically won’t need to use this directly - the responses are handled automatically by the connection.
These are responses to the corresponding ClientRequest variants.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
InitializeResponse(Box<InitializeResponse>)
Successful result returned for a initialize request.
AuthenticateResponse(AuthenticateResponse)
Successful result returned for a authenticate request.
LogoutResponse(LogoutResponse)
Successful result returned for a logout request.
NewSessionResponse(NewSessionResponse)
Successful result returned for a session/new request.
LoadSessionResponse(LoadSessionResponse)
Successful result returned for a session/load request.
ListSessionsResponse(ListSessionsResponse)
Successful result returned for a session/list request.
DeleteSessionResponse(DeleteSessionResponse)
Successful result returned for a session/delete request.
ForkSessionResponse(ForkSessionResponse)
unstable_session_fork only.Successful result returned for a session/fork request.
ResumeSessionResponse(ResumeSessionResponse)
Successful result returned for a session/resume request.
CloseSessionResponse(CloseSessionResponse)
Successful result returned for a session/close request.
SetSessionConfigOptionResponse(SetSessionConfigOptionResponse)
Successful result returned for a session/set_config_option request.
PromptResponse(PromptResponse)
Successful result returned for a session/prompt request.
ExtMethodResponse(ExtResponse)
Successful result returned by an extension method outside the core ACP method set.
MessageMcpResponse(MessageMcpResponse)
unstable_mcp_over_acp only.Successful result returned by an MCP-over-ACP mcp/message request.