#[non_exhaustive]pub struct AuthMethodEnvVar {
pub id: AuthMethodId,
pub name: String,
pub description: Option<String>,
pub vars: Vec<AuthEnvVar>,
pub link: Option<String>,
pub meta: Option<Map<String, Value>>,
}unstable_protocol_v2 only.Expand description
UNSTABLE
This capability is not part of the spec yet, and may be removed or changed at any point.
Environment variable authentication method.
The user provides credentials that the client passes to the agent as environment variables.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.id: AuthMethodIdUnique identifier for this authentication method.
name: StringHuman-readable name of the authentication method.
description: Option<String>Optional description providing more details about this authentication method.
vars: Vec<AuthEnvVar>The environment variables the client should set.
link: Option<String>Optional link to a page where the user can obtain their credentials.
meta: Option<Map<String, Value>>The _meta property is reserved by ACP to allow clients and agents to attach additional metadata to their interactions. Implementations MUST NOT make assumptions about values at these keys.
See protocol docs: Extensibility
Implementations
Sourceimpl AuthMethodEnvVar
impl AuthMethodEnvVar
pub fn new( id: impl Into<AuthMethodId>, name: impl Into<String>, vars: Vec<AuthEnvVar>, ) -> AuthMethodEnvVar
unstable_auth_methods only.Sourcepub fn link(self, link: impl IntoOption<String>) -> AuthMethodEnvVar
Available on crate feature unstable_auth_methods only.
pub fn link(self, link: impl IntoOption<String>) -> AuthMethodEnvVar
unstable_auth_methods only.Optional link to a page where the user can obtain their credentials.
Sourcepub fn description(
self,
description: impl IntoOption<String>,
) -> AuthMethodEnvVar
Available on crate feature unstable_auth_methods only.
pub fn description( self, description: impl IntoOption<String>, ) -> AuthMethodEnvVar
unstable_auth_methods only.Optional description providing more details about this authentication method.
Sourcepub fn meta(self, meta: impl IntoOption<Map<String, Value>>) -> AuthMethodEnvVar
Available on crate feature unstable_auth_methods only.
pub fn meta(self, meta: impl IntoOption<Map<String, Value>>) -> AuthMethodEnvVar
unstable_auth_methods only.The _meta property is reserved by ACP to allow clients and agents to attach additional metadata to their interactions. Implementations MUST NOT make assumptions about values at these keys.
See protocol docs: Extensibility