#[non_exhaustive]pub struct CancelRequestNotification {
pub request_id: RequestId,
pub meta: Option<Map<String, Value>>,
}unstable_protocol_v2 only.Expand description
UNSTABLE
This capability is not part of the spec yet, and may be removed or changed at any point.
Notification to cancel an ongoing request.
See protocol docs: Cancellation
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.request_id: RequestIdThe ID of the request to cancel.
meta: Option<Map<String, Value>>The _meta property is reserved by ACP to allow clients and agents to attach additional metadata to their interactions. Implementations MUST NOT make assumptions about values at these keys.
See protocol docs: Extensibility
Implementations
Sourceimpl CancelRequestNotification
impl CancelRequestNotification
Sourcepub fn new(request_id: impl Into<RequestId>) -> CancelRequestNotification
Available on crate feature unstable_cancel_request only.
pub fn new(request_id: impl Into<RequestId>) -> CancelRequestNotification
unstable_cancel_request only.Builds CancelRequestNotification with the required notification fields set; optional fields start unset or empty.
Sourcepub fn meta(
self,
meta: impl IntoOption<Map<String, Value>>,
) -> CancelRequestNotification
Available on crate feature unstable_cancel_request only.
pub fn meta( self, meta: impl IntoOption<Map<String, Value>>, ) -> CancelRequestNotification
unstable_cancel_request only.The _meta property is reserved by ACP to allow clients and agents to attach additional metadata to their interactions. Implementations MUST NOT make assumptions about values at these keys.
See protocol docs: Extensibility