#[non_exhaustive]pub struct DiffChange {
pub file_type: Option<DiffFileType>,
pub mime_type: Option<String>,
pub operation: DiffChangeOperation,
pub meta: Option<Map<String, Value>>,
}unstable_protocol_v2 only.Expand description
One file-level change described by a Diff.
Structured change metadata lets clients identify affected files and operations without parsing the text patch.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.file_type: Option<DiffFileType>File content kind.
Omitted or null means the content kind is unknown.
mime_type: Option<String>MIME type of the file contents.
Omitted or null means the MIME type is unknown.
operation: DiffChangeOperationFile operation-specific fields.
meta: Option<Map<String, Value>>The _meta property is reserved by ACP to allow clients and agents to attach additional metadata to their interactions. Implementations MUST NOT make assumptions about values at these keys.
See protocol docs: Extensibility
Implementations
Sourceimpl DiffChange
impl DiffChange
Sourcepub fn new(operation: DiffChangeOperation) -> DiffChange
pub fn new(operation: DiffChangeOperation) -> DiffChange
Builds DiffChange with the required fields set; optional fields start unset or empty.
Sourcepub fn add(path: impl Into<PathBuf>) -> DiffChange
pub fn add(path: impl Into<PathBuf>) -> DiffChange
Builds a file add change.
Sourcepub fn delete(path: impl Into<PathBuf>) -> DiffChange
pub fn delete(path: impl Into<PathBuf>) -> DiffChange
Builds a file delete change.
Sourcepub fn modify(path: impl Into<PathBuf>) -> DiffChange
pub fn modify(path: impl Into<PathBuf>) -> DiffChange
Builds a file modify change.
Sourcepub fn move_file(
old_path: impl Into<PathBuf>,
path: impl Into<PathBuf>,
) -> DiffChange
pub fn move_file( old_path: impl Into<PathBuf>, path: impl Into<PathBuf>, ) -> DiffChange
Builds a file move or rename change.
Sourcepub fn copy(
old_path: impl Into<PathBuf>,
path: impl Into<PathBuf>,
) -> DiffChange
pub fn copy( old_path: impl Into<PathBuf>, path: impl Into<PathBuf>, ) -> DiffChange
Builds a file copy change.
Sourcepub fn file_type(self, file_type: impl IntoOption<DiffFileType>) -> DiffChange
pub fn file_type(self, file_type: impl IntoOption<DiffFileType>) -> DiffChange
File content kind.
Omitted or null means the content kind is unknown.
Sourcepub fn mime_type(self, mime_type: impl IntoOption<String>) -> DiffChange
pub fn mime_type(self, mime_type: impl IntoOption<String>) -> DiffChange
MIME type of the file contents.
Omitted or null means the MIME type is unknown.
Sourcepub fn meta(self, meta: impl IntoOption<Map<String, Value>>) -> DiffChange
pub fn meta(self, meta: impl IntoOption<Map<String, Value>>) -> DiffChange
The _meta property is reserved by ACP to allow clients and agents to attach additional metadata to their interactions. Implementations MUST NOT make assumptions about values at these keys.
See protocol docs: Extensibility