#[non_exhaustive]pub struct Usage {
pub total_tokens: u64,
pub input_tokens: u64,
pub output_tokens: u64,
pub thought_tokens: Option<u64>,
pub cached_read_tokens: Option<u64>,
pub cached_write_tokens: Option<u64>,
pub meta: Option<Map<String, Value>>,
}unstable_protocol_v2 only.Expand description
UNSTABLE
This capability is not part of the spec yet, and may be removed or changed at any point.
Token usage information for completed session work.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.total_tokens: u64Sum of all token types across session.
input_tokens: u64Total input tokens.
output_tokens: u64Total output tokens.
thought_tokens: Option<u64>Total thought/reasoning tokens
cached_read_tokens: Option<u64>Total cache read tokens.
cached_write_tokens: Option<u64>Total cache write tokens.
meta: Option<Map<String, Value>>The _meta property is reserved by ACP to allow clients and agents to attach additional metadata to their interactions. Implementations MUST NOT make assumptions about values at these keys.
See protocol docs: Extensibility
Implementations
Sourceimpl Usage
impl Usage
Sourcepub fn new(total_tokens: u64, input_tokens: u64, output_tokens: u64) -> Usage
Available on crate feature unstable_end_turn_token_usage only.
pub fn new(total_tokens: u64, input_tokens: u64, output_tokens: u64) -> Usage
unstable_end_turn_token_usage only.Builds Usage with the required fields set; optional fields start unset or empty.
Sourcepub fn thought_tokens(self, thought_tokens: impl IntoOption<u64>) -> Usage
Available on crate feature unstable_end_turn_token_usage only.
pub fn thought_tokens(self, thought_tokens: impl IntoOption<u64>) -> Usage
unstable_end_turn_token_usage only.Total thought/reasoning tokens
Sourcepub fn cached_read_tokens(
self,
cached_read_tokens: impl IntoOption<u64>,
) -> Usage
Available on crate feature unstable_end_turn_token_usage only.
pub fn cached_read_tokens( self, cached_read_tokens: impl IntoOption<u64>, ) -> Usage
unstable_end_turn_token_usage only.Total cache read tokens.
Sourcepub fn cached_write_tokens(
self,
cached_write_tokens: impl IntoOption<u64>,
) -> Usage
Available on crate feature unstable_end_turn_token_usage only.
pub fn cached_write_tokens( self, cached_write_tokens: impl IntoOption<u64>, ) -> Usage
unstable_end_turn_token_usage only.Total cache write tokens.
Sourcepub fn meta(self, meta: impl IntoOption<Map<String, Value>>) -> Usage
Available on crate feature unstable_end_turn_token_usage only.
pub fn meta(self, meta: impl IntoOption<Map<String, Value>>) -> Usage
unstable_end_turn_token_usage only.The _meta property is reserved by ACP to allow clients and agents to attach additional metadata to their interactions. Implementations MUST NOT make assumptions about values at these keys.
See protocol docs: Extensibility