pub struct AcpAgentConfig { /* private fields */ }Expand description
Configuration for launching an ACP agent subprocess.
This is local SDK configuration, not an ACP wire-protocol type. It contains only the values used to launch the child process.
use agent_client_protocol::{AcpAgent, AcpAgentConfig};
let agent = AcpAgent::new(
AcpAgentConfig::new("python")
.arg("agent.py")
.env("RUST_LOG", "debug"),
);Implementations
Sourceimpl AcpAgentConfig
impl AcpAgentConfig
Sourcepub fn new(command: impl Into<PathBuf>) -> Self
pub fn new(command: impl Into<PathBuf>) -> Self
Create a configuration for the given executable or command name.
Sourcepub fn env(self, name: impl Into<String>, value: impl Into<String>) -> Self
pub fn env(self, name: impl Into<String>, value: impl Into<String>) -> Self
Set one environment variable for the child process.
Sourcepub fn environment(&self) -> &BTreeMap<String, String>
pub fn environment(&self) -> &BTreeMap<String, String>
Environment variables set for the child process.