DynamicHandlerGuard

Struct DynamicHandlerGuard 

pub struct DynamicHandlerGuard<R: Role> { /* private fields */ }
A guard that keeps a dynamic message handler registered.

Dropping the guard unregisters the handler. Use detach to keep the handler registered for the remaining lifetime of the connection.

Implementations

Source

impl<R: Role> DynamicHandlerGuard<R>

pub fn detach(self)

Keep the dynamic handler registered after this guard is dropped.

The handler remains registered until the connection itself shuts down. Unlike leaking the guard, detaching does not retain an extra ConnectionTo handle.